import sys
import numpy as np
import numba
from numba import njit, b1, i4, i8, f8
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
mod = 998244353

@njit((i8, i8), cache=True)
def mpow(a, n):
  p = 1
  while n:
    if n & 1:
      p = (p * a) % mod
    a = (a * a) % mod
    n >>= 1
  return p

@njit((i8[:],), cache=True)
def build(raw_data):
  bit = raw_data.copy()
  for i in range(len(bit)):
    j = i + (i & (- i))
    if j < len(bit):
      bit[j] += bit[i]
      bit[j] %= mod
  return bit

@njit((i8[:], i8), cache=True)
def get_sum(bit, i):
  s = 0
  while i:
    s += bit[i]
    i -= (i & (- i))
  return (s % mod)

@njit((i8[:], i8, i8), cache=True)
def add(bit, i, x):
  while i < len(bit):
    bit[i] += x
    bit[i] %= mod
    i += (i & (- i))

@njit((i8, i8[:]), cache=True)
def main(K, A):
  N = len(A)
  p = ((1 - mpow(K, (mod - 2))) % mod)
  pinv = mpow(p, (mod - 2))
  bitactive = np.zeros((N + 1), np.int64)
  bitcnt = np.zeros((N + 1), np.int64)
  half = (mod + 1) // 2
  ans = 0
  ans += (((((K * (K - 1)) // 2) % mod) * half) % mod)
  ans %= mod
  for i in range(K):
    x = A[i]
    add(bitcnt, x, 1)
    add(bitactive, x, mpow(pinv, (K - 1)))
  for i in range(K, N):
    x = A[i]
    lowcnt = get_sum(bitcnt, x)
    highcnt = (i - lowcnt)
    pt = mpow(p, i)
    activesumlow = ((get_sum(bitactive, x) * pt) % mod)
    activesumhigh = ((K - 1) - activesumlow)
    add(bitcnt, x, 1)
    add(bitactive, x, mpow(pinv, i))
    inv = 0
    inv += ((activesumlow * half) % mod)
    inv += (highcnt - activesumhigh)
    inv += ((activesumhigh * half) % mod)
    inv %= mod
    ans += inv
    ans %= mod
  return ans

(N, K) = map(int, readline().split())
A = np.array(read().split(), np.int64)
print(main(K, A))

