# File changed

import sys
import numpy as np
import numba
from numba import njit, b1, i4, i8, f8
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
MOD = 998244353

@njit((i8, i8), cache=True)
def mpow(a, n):
    'Calculates a^n mod MOD

    Args:
        a (int): The base.
        n (int): The exponent.

    Returns:
        int: The result of a^n mod MOD.
    '
    p = 1
    while n:
        if (n & 1):
            p = ((p * a) % MOD)
        a = ((a * a) % MOD)
        n >>= 1
    return p

@njit((i8[:],), cache=True)
def build(raw_data):
    'Builds a Fenwick tree

    Args:
        raw_data (numpy.ndarray): The data to build the tree from.

    Returns:
        numpy.ndarray: The Fenwick tree.
    '
    bit = raw_data.copy()
    for i in range(len(bit)):
        j = (i + (i & (- i)))
        if (j < len(bit)):
            bit[j] += bit[i]
            bit[j] %= MOD
    return bit

@njit((i8[:], i8), cache=True)
def get_sum(bit, i):
    'Gets the sum of the Fenwick tree up to index i

    Args:
        bit (numpy.ndarray): The Fenwick tree.
        i (int): The index to get the sum up to.

    Returns:
        int: The sum of the Fenwick tree up to index i.
    '
    s = 0
    while i:
        s += bit[i]
        i -= (i & (- i))
    return (s % MOD)

@njit((i8[:], i8, i8), cache=True)
def add(bit, i, x):
    'Adds x to the Fenwick tree at index i

    Args:
        bit (numpy.ndarray): The Fenwick tree.
        i (int): The index to add x to.
        x (int): The value to add to the Fenwick tree.
    '
    while (i < len(bit)):
        bit[i] += x
        bit[i] %= MOD
        i += (i & (- i))

@njit((i8, i8[:]), cache=True)
def main(K, A):
    'The main function

    Args:
        K (int): The number of elements to consider.
        A (numpy.ndarray): The array to consider.

    Returns:
        int: The result of the main function.
    '
    N = len(A)
    p = ((1 - mpow(K, (MOD - 2))) % MOD)
    p_inv = mpow(p, (MOD - 2))
    bit_active = np.zeros((N + 1), np.int64)
    bit_cnt = np.zeros((N + 1), np.int64)
    half = ((MOD + 1) // 2)
    ans = 0
    ans += (((((K * (K - 1)) // 2) % MOD) * half) % MOD)
    ans %= MOD
    for i in range(K):
        x = A[i]
        add(bit_cnt, x, 1)
        add(bit_active, x, mpow(p_inv, (K - 1)))
    for i in range(K, N):
        x = A[i]
        low_cnt = get_sum(bit_cnt, x)
        high_cnt = (i - low_cnt)
        pt = mpow(p, i)
        active_sum_low = ((get_sum(bit_active, x)