# File changed


class TwoSat:

    def __init__(self):
        self._n = 0
        self.scc = SccGraph(0)

    def __init__(self, n):
        self._n = n
        self._answer = [False] * n
        self.scc = SccGraph((2 * n))

    def add_clause(self, i, f, j, g):
        self.scc.add_edge(((2 * i) + (not f)), ((2 * j) + g))
        self.scc.add_edge(((2 * j) + (not g)), ((2 * i) + f))

    def satisfiable(self):
        id = self.scc.scc_ids()[1]
        for i in range(self._n):
            if (id[(2 * i)] == id[((2 * i) + 1)]):
                return False
            self._answer[i] = (id[(2 * i)] < id[((2 * i) + 1)])
        return True

    def answer(self):
        return self._answer

import sys

sys.setrecursionlimit(1000000)

class SccGraph:

    def __init__(self, n):
        self._n = n
        self.g = {}

    def num_vertices(self):
        return self._n

    def add_edge(self, frm, to):
        if (frm in self.g):
            self.g[frm].append(to)
        else:
            self.g[frm] = [to]

    def scc_ids(self):
        now_ord = group_num = 0
        visited = []
        low = [0] * self._n
        ord = [(- 1)] * self._n
        ids = [0] * self._n

        def dfs(self, v, now_ord, group_num):
            low[v] = ord[v] = now_ord
            now_ord += 1
            visited.append(v)
            if (v in self.g):
                for to in self.g[v]:
                    if (ord[to] == (- 1)):
                        (now_ord, group_num) = self(self, to, now_ord, group_num)
                        low[v] = min(low[v], low[to])
                    else:
                        low[v] = min(low[v], ord[to])
            if (low[v] == ord[v]):
                while True:
                    u = visited.pop()
                    ord[u] = self._n
                    ids[u] = group_num
                    if (u == v):
                        break
                group_num += 1
            return (now_ord, group_num)
        for i in range(self._n):
            if (ord[i] == (- 1)):
                (now_ord, group_num) = dfs(dfs, i, now_ord, group_num)
        for i in range(self._n):
            ids[i] = ((group_num - 1) - ids[i])
        return (group_num, ids)

    def scc(self):
        (group_num, ids) = self.scc_ids()
        counts = [0] * group_num
        for x in ids:
            counts[x] += 1
        groups = [[], ] * group_num
        for i in range(self._n):
            groups[ids[i]].append(i)
        return groups

    class Edge:

        def __init__(self, frm, to):
            self.frm = frm
            self.to = to

def main():
    input = sys.stdin.readline
    (N, d) = list(map(int, input().split()))
    xy = [list(map(int, input().split())) for _ in range(N)]
    ts = TwoSat(N)
    for i in range(N):
        for j in range((i + 1), N):
            (xi, yi) = xy[i]
            (xj, yj) = xy[j]
            if (abs((xi - xj)) < d):
                ts.add_clause(i, False, j, False)
            if (abs((xi - yj)) < d):
                ts.add_clause(i, False, j, True)
            if (abs((yi - xj)) < d):
                ts.add_clause(i, True, j, False)
            if (abs((yi - yj)) < d):
                ts.add_clause(i, True, j, True)
    if (not ts.satisfiable()):
        print('No')
        exit()
    print('Yes')
    answer = ts.answer()
    for i in range(N):
        (x, y) = xy[i]
        if answer[i]:
            print(x)
        else:
            print(y)

main()



