# File changed


class UnionFind():

    def __init__(self, n):
        'Initializes the UnionFind class

        Args:
            n (int): The number of elements in the UnionFind.
        '
        self.n = n
        self.par = [i for i in range(n)]
        self.rank = [0 for i in range(n)]
        self.siz = [1 for i in range(n)]

    def find(self, x):
        'Finds the root of the tree

        Args:
            x (int): The element to find the root of.

        Returns:
            int: The root of the tree.
        '
        if (self.par[x] == x):
            return x
        self.par[x] = self.find(self.par[x])
        return self.find(self.par[x])

    def unite(self, x, y):
        'Unites two trees

        Args:
            x (int): The first tree to unite.
            y (int): The second tree to unite.
        '
        x = self.find(x)
        y = self.find(y)
        if (x == y):
            return
        if (self.rank[x] > self.rank[y]):
            self.par[y] = x
            self.siz[x] += self.siz[y]
        else:
            self.par[x] = y
            self.siz[y] += self.siz[x]
            if (self.rank[x] == self.rank[y]):
                self.rank[y] += 1

    def same(self, x, y):
        'Checks if two elements are in the same tree

        Args:
            x (int): The first element to check.
            y (int): The second element to check.

        Returns:
            bool: Whether or not the two elements are in the same tree.
        '
        return (self.find(x) == self.find(y))

    def size(self, x):
        'Gets the size of the tree

        Args:
            x (int): The element to get the size of.

        Returns:
            int: The size of the tree.
        '
        return self.siz[self.find(x)]
(n, m) = map(int, input().split())
uf = UnionFind(n)
for i in range(m):
    (a, b) = map(int, input().split())
    a -= 1
    b -= 1
    uf.unite(a, b)
res = 0
for i in range(n):
    res = max(res, uf.size(i))
print(res)


