# File changed

import sys
import numpy as np
import numba
from numba import njit, b1, i4, i8, f8
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
mod = 1000000007

@njit((i8, i8), cache=True)
def mpow(a, n):
    p = 1
    while n:
        if (n & 1):
            p = ((p * a) % mod)
        a = ((a * a) % mod)
        n >>= 1
    return p

@njit((i8,), cache=True)
def fact_table(N):
    'Compute 0!, 1!, ..., (N-1)! and their inverses modulo MOD. \n\n    Parameters\n    ----------\n    N : int\n        length of the output array. \n\n    Returns\n    -------\n    fact : np.ndarray\n        0!, 1!, ..., (N-1)!\n\n    fact_inv : np.ndarray\n        inverse of 0!, 1!, ..., (N-1)! modulo MOD. \n    '
    fact = np.empty(N, np.int64)
    fact[0] = 1
    for n in range(1, N):
        fact[n] = ((n * fact[(n - 1)]) % mod)
    factinv = np.empty(N, np.int64)
    factinv[(N - 1)] = mpow(fact[(N - 1)], (mod - 2))
    for n in range((N - 1), 0, (- 1)):
        factinv[(n - 1)] = ((factinv[n] * n) % mod)
    return (fact, factinv)

@njit((i8, i8[:]), cache=True)
def main(H, P):
    (fact, factinv) = fact_table((1 << 20))
    inv = np.zeros((1 << 20), np.int64)
    inv[1:] = ((factinv[1:] * fact[:(- 1)]) % mod)
    f = np.ones_like(P)
    finv = np.ones_like(P)
    g = np.ones_like(P)
    g[0] = 0
    for v in range(2, (1 << H)):
        parent = (v >> 1)
        f[v] = ((f[parent] * parent) % mod)
        finv[v] = ((finv[parent] * inv[parent]) % mod)
        g[v] = ((((finv[v] * finv[v]) % mod) * inv[v]) % mod)
    dp1 = np.zeros((1 << H), np.int64)
    dp2 = np.zeros((1 << H), np.int64)
    ws = np.zeros((1 << H), np.int64)
    ptr = 0
    ans = 0
    for x1 in range(1, (1 << H)):
        (l, r) = (x1, (x1 + 1))
        while ((2 * l) < (1 << H)):
            (l, r) = ((2 * l), (2 * r))
        for v in range(l, r):
            pv = ((((f[v] * v) % mod) * finv[x1]) % mod)
            w = P[v]
            pw = pv
            while w:
                pw = ((pw * w) % mod)
                if (dp1[w] == 0):
                    ws[ptr] = w
                    ptr += 1
                dp1[w] += pw
                dp2[w] += ((pw * pw) % mod)
                w >>= 1
        for x2 in ws[:ptr]:
            dp1[x2] %= mod
            dp2[x2] %= mod
            x = (((dp1[x2] ** 2) - dp2[x2]) % mod)
            x = ((x * inv[2]) % mod)
            coef = ((((f[x1] * f[x2]) % mod) ** 2) % mod)
            x = ((x * coef) % mod)
            (p1, p2) = ((x1 >> 1), (x2 >> 1))
            coef = ((g[x1] * g[x2]) % mod)
            coef -= ((g[p1] * g[x2]) % mod)
            coef -= ((g[x1] * g[p2]) % mod)
            coef += ((g[p1] * g[p2]) % mod)
            coef %= mod
            ans += ((coef * x) % mod)
        for x2 in ws[:ptr]:
            dp1[x2] = 0
            dp2[x2] = 0
        ptr = 0
    return (ans % mod)
H = int(readline())
P = np.zeros((1 << H), np.int64)
P[(1 << (H - 1)):] = ((np.array(read().split(), np.int64) - 1) | (1 << (H - 1)))
print(main(H, P))

