# File changed

import sys
import numpy as np
import numba
from numba import njit, b1, i4, i8, f8
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
MOD = 1000000007

def mpow(a, n):
    p = 1
    while n:
        if (n & 1):
            p = ((p * a) % MOD)
        a = ((a * a) % MOD)
        n >>= 1
    return p

def fact_table(N):
    'Compute 0!, 1!, ..., (N-1)! and their inverses modulo MOD. \n\n    Parameters\n    ----------\n    N : int\n        length of the output array. \n\n    Returns\n    -------\n    fact : np.ndarray\n        0!, 1!, ..., (N-1)!\n\n    fact_inv : np.ndarray\n        inverse of 0!, 1!, ..., (N-1)! modulo MOD. \n    '
    fact = np.empty(N, np.int64)
    fact[0] = 1
    for n in range(1, N):
        fact[n] = ((n * fact[(n - 1)]) % MOD)
    fact_inv = np.empty(N, np.int64)
    fact_inv[(N - 1)] = mpow(fact[(N - 1)], (MOD - 2))
    for n in range((N - 1), 0, (- 1)):
        fact_inv[(n - 1)] = ((fact_inv[n] * n) % MOD)
    return (fact, fact_inv)

def main(H, P):
    (fact, fact_inv) = fact_table((1 << 20))
    inv = np.zeros((1 << 20), np.int64)
    inv[1:] = ((fact_inv[1:] * fact[:(- 1)]) % MOD)
    f = np.ones_like(P)
    f_inv = np.ones_like(P)
    g = np.ones_like(P)
    g[0] = 0
    for v in range(2, (1 << H)):
        parent = (v >> 1)
        f[v] = ((f[parent] * parent) % MOD)
        f_inv[v] = ((f_inv[parent] * inv[parent]) % MOD)
        g[v] = ((((f_inv[v] * f_inv[v]) % MOD) * inv[v]) % MOD)
    dp1 = np.zeros((1 << H), np.int64)
    dp2 = np.zeros((1 << H), np.int64)
    ws = np.zeros((1 << H), np.int64)
    ptr = 0
    ans = 0
    for x1 in range(1, (1 << H)):
        (l, r) = (x1, (x1 + 1))
        while ((2 * l) < (1 << H)):
            (l, r) = ((2 * l), (2 * r))
        for v in range(l, r):
            pv = ((((f[v] * v) % MOD) * f_inv[x1]) % MOD)
            w = P[v]
            pw = pv
            while w:
                pw = ((pw * w) % MOD)
                if (dp1[w] == 0):
                    ws[ptr] = w
                    ptr += 1
                dp1[w] += pw
                dp2[w] += ((pw * pw) % MOD)
                w >>= 1
        for x2 in ws[:ptr]:
            dp1[x2] %= MOD
            dp2[x2] %= MOD
            x = (((dp1[x2] ** 2) - dp2[x2]) % MOD)
            x = ((x * inv[2]) % MOD)
            coef = ((((f[x1] * f[x2]) % MOD) ** 2) % MOD)
            x = ((x * coef) % MOD)
            (p1, p2) = ((x1 >> 1), (x2 >> 1))
            coef = ((g[x1] * g[x2]) % MOD)
            coef -= ((g[p1] * g[x2]) % MOD)
            coef -= ((g[x1] * g[p2]) % MOD)
            coef += ((g[p1] * g[p2]) % MOD)
            coef %= MOD
            ans += ((coef * x) % MOD)
        for x2 in ws[:ptr]:
            dp1[x2] = 0
            dp2[x2] = 0
        ptr = 0
    return (ans % MOD)
H = int(readline())
P = np.zeros((1 << H), np.int64)
P[(1 << (H - 1)):] = ((np.array(read().split(), np.int64) - 1) | (1 << (H - 1)))
print(main(H, P))


