# File changed

import os
import sys
import numpy as np

def solve(inp):
    'Solves the problem

    Args:
        inp (list): The input data.

    Returns:
        list: The solution.
    '
    n = inp[0]
    xxx = inp[1::2]
    yyy = inp[2::2]
    xxx_idx = np.argsort(xxx)
    yyy_idx = np.argsort(yyy)
    xxx_num = np.argsort(xxx_idx)
    yyy_num = np.argsort(yyy_idx)

    def get_xy_by_xi(xi):
        'Gets the x and y values by the x index

        Args:
            xi (int): The x index.

        Returns:
            tuple: The x and y values.
        '
        i = xxx_idx[xi]
        return (xxx[i], yyy[i])

    def calc_time(lx, ly, rx, ry, llt, lrt, rlt, rrt, lpxi, rnxi, rook_cnt):
        'Calculates the time

        Args:
            lx (int): The left x value.
            ly (int): The left y value.
            rx (int): The right x value.
            ry (int): The right y value.
            llt (int): The left left time.
            lrt (int): The left right time.
            rlt (int): The right left time.
            rrt (int): The right right time.
            lpxi (int): The left x index.
            rnxi (int): The right x index.
            rook_cnt (int): The rook count.

        Returns:
            tuple: The left x, left y, right x, right y, left left time, left right time, right left time,
                and right right time.
        '
        (lpx, lpy) = get_xy_by_xi(lpxi)
        (rnx, rny) = get_xy_by_xi(rnxi)
        diag_t = ((abs((rnx - lpx)) + abs((rny - lpy))) - rook_cnt)
        lllt = (((llt + abs((rnx - lx))) + abs((rny - ly))) + diag_t)
        llrt = (((llt + abs((lx - lpx))) + abs((ly - lpy))) + diag_t)
        lrlt = (((lrt + abs((rnx - rx))) + abs((rny - ry))) + diag_t)
        lrrt = (((lrt + abs((rx - lpx))) + abs((ry - lpy))) + diag_t)
        rllt = (((rlt + abs((rnx - lx))) + abs((rny - ly))) + diag_t)
        rlrt = (((rlt + abs((lx - lpx))) + abs((ly - lpy))) + diag_t)
        rrlt = (((rrt + abs((rnx - rx))) + abs((rny - ry))) + diag_t)
        rrrt = (((rrt + abs((rx - lpx))) + abs((ry - lpy))) + diag_t)
        llt = min(lllt, lrlt)
        lrt = min(llrt, lrrt)
        rlt = min(rllt, rrlt)
        rrt = min(rlrt, rrrt)
        return (lpx, lpy, rnx, rny, llt, lrt, rlt, rrt)
    free = np.zeros(n, dtype=np.int8)
    for i in range(n):
        xi = xxx_num[i]
        yi = yyy_num[i]
        px_i = ((- 1) if (xi == 0) else xxx_idx[(xi - 1)])
        nx_i = ((- 2) if (xi == (n - 1)) else xxx_idx[(xi + 1)])
        py_i = ((- 3) if (yi == 0) else yyy_idx[(yi - 1)])
        ny_i = ((- 4) if (yi == (n - 1)) else yyy_idx[(yi + 1)])
        if ((px_i == py_i) or (px_i == ny_i)):
            free[(xi - 1)] = 1
        if ((nx_i == py_i) or (nx_i == ny_i)):
            free[xi] = 1
    free_l = np.zeros(n, dtype=np.int64)
    free_r = np.zeros(n, dtype=np.int64)
    l = 0
    for xi in range((n - 1)):
        if (free[xi] == 0):
            l = (xi + 1)
        free_l[(xi + 1)] = l
    r = (n - 1)
    free_r[r] = r
    for xi in range((n - 2), (- 1), (- 1)):
        if (free[xi] == 0):
            r = xi
        free_r[xi] = r
    extra_l = np.zeros(n, dtype=np.int64)
    extra_r = np.zeros(n, dtype=np.int64)
    INF = (10 ** 18)
    lxi = 0
    while (lxi < n):
        rxi = free_r[lxi]
        if (lxi == rxi):
            lxi = (rxi + 1)
            continue
        li = xxx_idx[lxi]
        ri = xxx_idx[rxi]
        lyi = yyy_num[li]
        ryi = yyy_num[ri]
        (lyi, ryi) = (min(lyi, ryi), max(lyi, ryi))
        original_li = lxi
        lx = xxx[li]
        ly = yyy[li]
        rx = xxx[ri]
        ry = yyy[ri]
        (llt, lrt,