# File changed

import sys
import numpy as np

def addBIT(itemCount, items, i, value):
    'Adds a value to the BIT

    Args:
        itemCount (int): The number of items in the BIT.
        items (numpy.ndarray): The BIT.
        i (int): The index to add the value to.
        value (int): The value to add.
    '
    while (i <= itemCount):
        items[i] += value
        i += (i & (- i))

def sumFromStart(items, end):
    'Sums the items from the start of the BIT

    Args:
        items (numpy.ndarray): The BIT.
        end (int): The index to end the sum at.

    Returns:
        int: The sum of the items.
    '
    summary = 0
    i = end
    while (i > 0):
        summary += items[i]
        i -= (i & (- i))
    return summary

def sumBIT(items, start, end):
    'Sums the items from the start of the BIT

    Args:
        items (numpy.ndarray): The BIT.
        start (int): The index to start the sum at.
        end (int): The index to end the sum at.

    Returns:
        int: The sum of the items.
    '
    summary = (sumFromStart(items, end) - sumFromStart(items, (start - 1)))
    return summary

def main(N, Q, C, queries, orderByR, mostRightColorIndex, bitArray):
    'Performs the main logic of the program

    Args:
        N (int): The number of items in the BIT.
        Q (int): The number of queries to perform.
        C (numpy.ndarray): The colors of the items.
        queries (numpy.ndarray): The queries to perform.
        orderByR (numpy.ndarray): The queries ordered by their right index.
        mostRightColorIndex (numpy.ndarray): The most right index of each color.
        bitArray (numpy.ndarray): The BIT.

    Returns:
        numpy.ndarray: The answers to the queries.
    '
    ans = np.zeros(Q, dtype=np.int64)
    qindex = 0
    for n in range(N):
        if (Q <= qindex):
            break
        if (0 < mostRightColorIndex[C[n]]):
            addBIT(N, bitArray, mostRightColorIndex[C[n]], (- 1))
        mostRightColorIndex[C[n]] = (n + 1)
        addBIT(N, bitArray, (n + 1), 1)
        while ((qindex < Q) and ((n + 1) == queries[orderByR[qindex]][1])):
            tmpIndex = orderByR[qindex]
            start = queries[tmpIndex][0]
            end = queries[tmpIndex][1]
            ans[tmpIndex] = sumBIT(bitArray, start, end)
            qindex += 1
    return ans
if (sys.argv[(- 1)] == 'ONLINE_JUDGE'):
    from numba import njit
    from numba.pycc import CC
    cc = CC('my_module')
    cc.export('addBIT', '(i8,i8[:],i8,i8)')(addBIT)
    addBIT = njit(addBIT)
    cc.export('