# File changed

import sys
from bisect import bisect_left
from collections import defaultdict
from itertools import accumulate

class UnionFind():

  def __init__(self, n):
    self.table = ([-1] * n)

  def _root(self, x):
    stack = []
    tbl = self.table
    while tbl[x] >= 0:
      stack.append(x)
      x = tbl[x]
    for y in stack:
      tbl[y] = x
    return x

  def find(self, x, y):
    return self._root(x) == self._root(y)

  def unite(self, x, y):
    r1 = self._root(x)
    r2 = self._root(y)
    if r1 == r2:
      return
    d1 = self.table[r1]
    d2 = self.table[r2]
    if d1 <= d2:
      self.table[r2] = r1
      self.table[r1] += d2
    else:
      self.table[r1] = r2
      self.table[r2] += d1

  def get_size(self, x):
    return - self.table[self._root(x)]

def solve():
  n, m = map(int, sys.stdin.buffer.readline().split())
  extradurabilities = [0] * n
  selfloopdurabilities = [[] for _ in range(n)]
  outdegrees = [0] * n
  baseoperationcount = 0
  uft = UnionFind(n)
  mp = map(int, sys.stdin.buffer.read().split())
  for a, b, c in zip(mp, mp, mp):
    a -= 1
    b -= 1
    outdegrees[a] += 1
    if a == b:
      if c >= 2:
        selfloopdurabilities[a].append(c)
      continue
    uft.unite(a, b)
    extradurabilities[a] += (c - 1)
    baseoperationcount += 1
  components = defaultdict((lambda : [0, 0, 0, []]))
  for i in range(n):
    r = uft._root(i)
    item = components[r]
    item[0] += 1
    item[1] = max(item[1], outdegrees[i])
    item[2] += extradurabilities[i]
    item[3].extend(selfloopdurabilities[i])
  existsinitialcatalystonmovingpath = False
  existsinitialcatalystatselfloop = False
  suppliedcatalyst = 0
  demandedcatalyst = 0
  selfloopcatalystscost1 = []
  selfloopcatalystscost2 = []
  for i, (cnt, deg, dur, sel) in components.items():
    if cnt == 1:
      if deg == 1:
        selfloopcatalystscost2.extend((c - 2 for c in sel))
      elif len(sel) >= 1:
        selfloopcatalystscost1.extend((c - 1 for c in sel))
        existsinitialcatalystatselfloop = True
      continue
    if deg == 1:
      suppliedcatalyst += dur
      demandedcatalyst += 1
    else:
      suppliedcatalyst += dur
      if dur >= 1:
        existsinitialcatalystonmovingpath = True
      elif len(sel) >= 1:
        existsinitialcatalystatselfloop = True
    selfloopcatalystscost1.extend((c - 1 for c in sel))
  if demandedcatalyst == 0:
    return baseoperationcount
  if (not existsinitialcatalystonmovingpath) and (not existsinitialcatalystatselfloop):
    return -1
  if suppliedcatalyst >= demandedcatalyst:
    if existsinitialcatalystonmovingpath:
      return baseoperationcount + demandedcatalyst
    else:
      return baseoperationcount + demandedcatalyst + 1
  selfloopcatalystscost1.sort(reverse=True)
  selfloopcatalystscost2.sort(reverse=True)
  acc1 = [0] + list(accumulate(selfloopcatalystscost1))
  acc2 = [0] + list(accumulate(selfloopcatalystscost2))
  shortage = demandedcatalyst - suppliedcatalyst
  if acc1[-1] + acc2[-1] < shortage:
    return -1
  cost = 10**18
  for use1 in range(0 if existsinitialcatalystonmovingpath else 1, len(acc1)):
    cat = acc1[use1]
    remaining = shortage - cat
    if remaining <= 0:
      cost = min(cost, use1)
      break
    if remaining > acc2[-1]:
      continue
    use2 = bisect_left(acc2, remaining)
    cost = min(cost, use1 + 2 * use2)
  return baseoperationcount + demandedcatalyst + cost

print(solve())

