import sys

from bisect import bisect_left
from collections import defaultdict
from itertools import accumulate


class UnionFind:
    def __init__(self, n):
        self.table = [-1] * n

    def _root(self, x):
        stack = []
        tbl = self.table
        while tbl[x] >= 0:
            stack.append(x)
            x = tbl[x]
        for y in stack:
            tbl[y] = x
        return x

    def find(self, x, y):
        return self._root(x) == self._root(y)

    def unite(self, x, y):
        r1 = self._root(x)
        r2 = self._root(y)
        if r1 == r2:
            return
        d1 = self.table[r1]
        d2 = self.table[r2]
        if d1 <= d2:
            self.table[r2] = r1
            self.table[r1] += d2
        else:
            self.table[r1] = r2
            self.table[r2] += d1

    def get_size(self, x):
        return -self.table[self._root(x)]


@pytest.mark.parametrize('test_input,expected', [
    ('1 1\n1 1 1', 1),
    ('2 1\n1 1 1', 2),
    ('2 1\n1 1 2', 2),
    ('2 1\n1 1 3', 2),
    ('2 1\n1 1 4', 2),
    ('2 1\n1 1 5', 2),
    ('2 1\n1 1 6', 2),
    ('2 1\n1 1 7', 2),
    ('2 1\n1 1 8', 2),
    ('2 1\n1 1 9', 2),
    ('2 1\n1 1 10', 2),
    ('2 1\n1 1 11', 2),
    ('2 1\n1 1 12', 2),
    ('2 1\n1 1 13', 2),
    ('2 1\n1 1 14', 2),
    ('2 1\n1 1 15', 2),
    ('2 1\n1 1 16', 2),
    ('2 1\n1 1 17', 2),
    ('2 1\n1 1 18', 2),
    ('2 1\n1 1 19', 2),
    ('2 1\n1 1 20', 2),
    ('2 1\n1 1 21', 2),
    ('2 1\n1 1 22', 2),
    ('2 1\n1 1 23', 2),
    ('2 1\n1 1 24', 2),
    ('2 1\n1 1 25', 2),
    ('2 1\n1 1 26', 2),
    ('2 1\n1 1 27', 2),
    ('2 1\n1 1 28', 2),
    ('2 1\n1 1 29', 2),
    ('2 1\n1 1 30', 2),
    ('2 1\n1 1 31', 2),
    ('2 1\n1 1 32', 2),
    ('2 1\n1 1 33', 2),
    ('2 1\n1 1 34', 2),
    ('2 1\n1 1 35', 2),
    ('2 1\n1 1 36', 2),
    ('2 1\n1 1 37', 2),
    ('2 1\n1 1 38', 2),
    ('2 1\n1 1 39', 2),
    ('2 1\n1 1 40', 2),
    ('2 1\n1 1 41', 2),
    ('2 1\n1 1 42', 2),
    ('2 1\n1 1 43', 2),
    ('2 1\n1 1 44', 2),
    ('2 1\n1 1 45', 2),
    ('2 1\n1 1 46', 2),
    ('2 1\n1 1 47', 2),
    ('2 1\n1 1 48', 2),
    ('2 1\n1 1 49', 2),
    ('2 1\n1 1 50', 2),
    ('2 1\n1 1 51', 2),
    ('2 1\n1 1 52', 2),
    ('2 1\n1 1 53', 2),
    ('2 1\n1 1 54', 2),
    ('2 1\n1 1 55', 2),
    ('2 1\n1 1 56', 2),
    ('2 1\n1 1 57', 2),
    ('2 1\n1 1 58', 2),
    ('2 1\n1 1 59', 2),
    ('2 1\n1 1 60', 2),
    ('2 1\n1 1 61', 2),
    ('2 1\n1 1 62', 2),
    ('2 1\n1 1 63', 2),
    ('2 1\n1 1 64', 2),
    ('2 1\n1 1 65', 2),
    ('2 1\n1 1 66', 2),
    ('2 1\n1 1 67', 2),
    ('2 1\n1 1 68', 2),
    ('2 1\n1 1 69', 2),
    ('2 1\n1 1 70', 2),
    ('2 1\n1 1 71', 2),
    ('2 1\n1 1 72', 2),
    ('2 1\n1 1 73', 2