# File changed

import os
import cmath
import math
import sys
if os.getenv('LOCAL'):
    sys.stdin = open('_in.txt', 'r')
sys.setrecursionlimit((10 ** 9))
inf = float('inf')
iinf = (10 ** 18)
mod = ((10 ** 9) + 7)

class Point():
    '\n    2次元空間上の点\n    '
    CCW_COUNTER_CLOCKWISE = 1
    CCW_CLOCKWISE = (- 1)
    CCW_ONLINE_BACK = 2
    CCW_ONLINE_FRONT = (- 2)
    CCW_ON_SEGMENT = 0

    def __init__(self, x: float, y: float):
        self.c = complex(x, y)

    @property
    def x(self):
        return self.c.real

    @property
    def y(self):
        return self.c.imag

    @staticmethod
    def from_complex(c: complex):
        return Point(c.real, c.imag)

    @staticmethod
    def from_polar(r: float, phi: float):
        c = cmath.rect(r, phi)
        return Point(c.real, c.imag)

    def __add__(self, p):
        '\n        :param Point p:\n        '
        c = (self.c + p.c)
        return Point(c.real, c.imag)

    def __iadd__(self, p):
        '\n        :param Point p:\n        '
        self.c += p.c
        return self

    def __sub__(self, p):
        '\n        :param Point p:\n        '
        c = (self.c - p.c)
        return Point(c.real, c.imag)

    def __isub__(self, p):
        '\n        :param Point p:\n        '
        self.c -= p.c
        return self

    def __mul__(self, f: float):
        c = (self.c * f)
        return Point(c.real, c.imag)

    def __imul__(self, f: float):
        self.c *= f
        return self

    def __truediv__(self, f: float):
        c = (self.c / f)
        return Point(c.real, c.imag)

    def __itruediv__(self, f: float):
        self.c /= f
        return self

    def __repr__(self):
        return '({}, {})'.format(round(self.x, 10), round(self.y, 10))

    def __neg__(self):
        c = (- self.c)
        return Point(c.real, c.imag)

    def __eq__(self, p):
        return (abs((self.c - p.c)) < EPS)

    def __abs__(self):
        return abs(self.c)

    def __lt__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < (- EPS))))

    def __le__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < EPS)))

    def __gt__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > EPS)))

    def __ge__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > (- EPS))))

    @staticmethod
    def ccw(a, b, c):
        '\n        線分 ab に対する c の位置\n        線分上にあるか判定するだけなら on_segment とかのが速い\n        Verify: http://judge.u-aizu.ac.jp/onlinejudge/description.jsp?id=CGL_1_C&lang=ja\n        :param Point a:\n        :param Point b:\n        :param Point c:\n        '
        b = (b - a)
        c = (c - a)
        det = b.det(c)
        if (det > EPS):
            return Point.CCW_COUNTER_CLOCKWISE
        if (det < (- EPS)):
            return Point.CCW_CLOCKWISE
        if (b.dot(c) < (- EPS)):
            return Point.CCW_ONLINE_BACK
        if (b.dot((b - c)) < (- EPS)):
            return Point.CCW_ONLINE_FRONT
        return Point.CCW_ON_SEGMENT

    def dot(self, p):
        '\n        内積\n        :param Point p:\n        :rtype: float\n        '
        return ((self.x * p.x) + (self.y * p.y))

    def det(self, p):
        '\n        外積\n        :param Point p:\n        :rtype: float\n        '
        return ((self.x * p.y) - (self.y * p.x))

    def dist(self, p):
        '\n        距離\n        :param Point p:\n        :rtype: float\n        '
        return abs((self.c - p.c))

    def norm(self):
        '\n        原点からの距離\n        :rtype: float\n        '
        return abs(self.c)

    def phase(self):
        '\n        原点からの角度\n        :rtype: float\n        '
        return cmath