# File changed

import os
import cmath
import math
import sys
if os.getenv('LOCAL'):
    sys.stdin = open('_in.txt', 'r')
sys.setrecursionlimit((10 ** 9))
INF = float('inf')
IINF = (10 ** 18)
MOD = ((10 ** 9) + 7)

class Point():
    CCW_COUNTER_CLOCKWISE = 1
    CCW_CLOCKWISE = (- 1)
    CCW_ONLINE_BACK = 2
    CCW_ONLINE_FRONT = (- 2)
    CCW_ON_SEGMENT = 0

    def __init__(self, x: float, y: float):
        self.c = complex(x, y)

    @property
    def x(self):
        return self.c.real

    @property
    def y(self):
        return self.c.imag

    @staticmethod
    def from_complex(c: complex):
        return Point(c.real, c.imag)

    @staticmethod
    def from_polar(r: float, phi: float):
        c = cmath.rect(r, phi)
        return Point(c.real, c.imag)

    def __add__(self, p):
        c = (self.c + p.c)
        return Point(c.real, c.imag)

    def __iadd__(self, p):
        self.c += p.c
        return self

    def __sub__(self, p):
        c = (self.c - p.c)
        return Point(c.real, c.imag)

    def __isub__(self, p):
        self.c -= p.c
        return self

    def __mul__(self, f: float):
        c = (self.c * f)
        return Point(c.real, c.imag)

    def __imul__(self, f: float):
        self.c *= f
        return self

    def __truediv__(self, f: float):
        c = (self.c / f)
        return Point(c.real, c.imag)

    def __itruediv__(self, f: float):
        self.c /= f
        return self

    def __repr__(self):
        return '({}, {})'.format(round(self.x, 10), round(self.y, 10))

    def __neg__(self):
        c = (- self.c)
        return Point(c.real, c.imag)

    def __eq__(self, p):
        return (abs((self.c - p.c)) < EPS)

    def __abs__(self):
        return abs(self.c)

    def __lt__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < (- EPS))))

    def __le__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < EPS)))

    def __gt__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > EPS)))

    def __ge__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > (- EPS))))

    @staticmethod
    def ccw(a, b, c):
        b = (b - a)
        c = (c - a)
        det = b.det(c)
        if (det > EPS):
            return Point.CCW_COUNTER_CLOCKWISE
        if (det < (- EPS)):
            return Point.CCW_CLOCKWISE
        if (b.dot(c) < (- EPS)):
            return Point.CCW_ONLINE_BACK
        if (b.dot((b - c)) < (- EPS)):
            return Point.CCW_ONLINE_FRONT
        return Point.CCW_ON_SEGMENT

    def dot(self, p):
        return ((self.x * p.x) + (self.y * p.y))

    def det(self, p):
        return ((self.x * p.y) - (self.y * p.x))

    def dist(self, p):
        return abs((self.c - p.c))

    def norm(self):
        return abs(self.c)

    def phase(self):
        return cmath.phase(self.c)

    def angle(self, p, q):
        return ((((cmath.phase((q.c - self.c)) - cmath.phase((p.c - self.c))) + PI) % TAU) - PI)

    def area(self, p, q):
        return abs(((p - self).det((q - self)) / 2))

    def projection_point(self, p, q, allow_outer=False):
        diff_q = (q - p)
        r = ((self - p).dot(diff_q) / abs(diff_q))
        phase = diff_q.phase()
        ret = (Point.from_polar(r, phase) + p)
        if (allow_outer or ((p - ret).dot((q - ret)) < EPS)):
            return ret
        return None

    def reflection_point(self, p, q):
        r = abs((self - p))
        angle = p.angle(q, self)
        angle = ((q - p).phase() - angle)
        return (Point.from_polar(r, angle) + p)

    def on_segment(self, p, q, allow_side=True):
        if ((not allow_side) and ((self == p) or (self == q))):
