from collections import deque
from typing import Optional

class BreadthFirstSearch(object):
    __slots__ = ['shape', 'pushed', '_deque', '_getter', '_setter']

    def __init__(self, shape: Union[(int, Iterable[int])]):
        self.shape = ((shape,) if isinstance(shape, int) else tuple(shape))
        self.pushed = nd.zeros(self.shape, type=bool)
        self._deque = deque()
        self._getter = nd.getter[len(self.shape)]
        self._setter = nd.setter[len(self.shape)]

    def push(self, position: Tuple[int]):
        if (not self._getter(self.pushed, position)):
            self._setter(self.pushed, position, True)
            self._deque.append(position)

    def peek(self) -> Optional[Tuple[int]]:
        return (self._deque[0] if self._deque else None)

    def pop(self) -> Optional[Tuple[int]]:
        return (self._deque.popleft() if self._deque else None)

    def __bool__(self):
        return bool(self._deque)

(N, M) = inputs(int)
(A, B, C) = inputs_2d_T(N, int)
(D, E, F) = inputs_2d_T(M, int)
xs = sorted(set(C))
ys = sorted(set(D))
xguard = nd.zeros(((len(xs) + 1), (len(ys) + 1)), type=bool)
yguard = nd.zeros(((len(xs) + 1), (len(ys) + 1)), type=bool)
for (a, b, c) in zip(A, B, C):
    c = bisect_right(xs, c)
    a = (bisect_left(ys, a) + 1)
    b = bisect_right(ys, b)
    for y in range(a, b):
        xguard[c][y] = True
for (d, e, f) in zip(D, E, F):
    d = bisect_right(ys, d)
    e = (bisect_left(xs, e) + 1)
    f = bisect_right(xs, f)
    for x in range(e, f):
        yguard[x][d] = True
cow = (bisect_right(xs, 0), bisect_right(ys, 0))
bfs = BreadthFirstSearch(shape=((len(xs) + 1), (len(ys) + 1)))
bfs.push(cow)
area = 0
while bfs:
    (xi, yi) = bfs.pop()
    if ((0 < xi < len(xs)) and (0 < yi < len(ys))):
        area += ((xs[xi] - xs[(xi - 1)]) * (ys[yi] - ys[(yi - 1)]))
        if (not xguard[xi][yi]):
            bfs.push(((xi - 1), yi))
        if (not xguard[(xi + 1)][yi]):
            bfs.push(((xi + 1), yi))
        if (not yguard[xi][yi]):
            bfs.push((xi, (yi - 1)))
        if (not yguard[xi][(yi + 1)]):
            bfs.push((xi, (yi + 1)))
    else:
        area = 'INF'
        break
print(area)



