# File changed

import sys
import numpy as np

def numba_compile(numba_config):
    import os, sys
    if (sys.argv[(- 1)] == 'ONLINE_JUDGE'):
        from numba import njit
        from numba.pycc import CC
        cc = CC('my_module')
        for (func, signature) in numba_config:
            globals()[func.__name__] = njit(signature)(func)
            cc.export(func.__name__, signature)(func)
        cc.compile()
        exit()
    elif (os.name == 'posix'):
        exec(f"from my_module import {','.join((func.__name__ for (func, _) in numba_config))}")
        for (func, _) in numba_config:
            globals()[func.__name__] = vars()[func.__name__]
    else:
        from numba import njit
        for (func, signature) in numba_config:
            globals()[func.__name__] = njit(signature, cache=True)(func)
        print('compiled!', file=sys.stderr)
mod = ((10 ** 9) + 7)

def pow_mod(base, exp):
    exp %= (mod - 1)
    res = 1
    while exp:
        if (exp % 2):
            res = ((res * base) % mod)
        base = ((base * base) % mod)
        exp //= 2
    return res

def comb_cunstruct(n):
    fac = np.empty((n + 1), dtype=np.int64)
    facinv = np.empty((n + 1), dtype=np.int64)
    fac[0] = f = 1
    for i in range(1, (n + 1)):
        f = ((f * i) % mod)
        fac[i] = f
    f = pow_mod(f, (- 1))
    for i in range(n, (- 1), (- 1)):
        facinv[i] = f
        f = ((f * i) % mod)
    return (fac, facinv)

def comb(n, r, fac, facinv):
    return ((((fac[n] * facinv[r]) % mod) * facinv[(n - r)]) % mod)

def rerooting(n, edges, fac, facinv):
    identity = (1, 0)

    def merge(a, b):
        return (((((a[0] * b[0]) % mod) * comb((a[1] + b[1]), a[1], fac, facinv)) % mod), (a[1] + b[1]))

    def add_node(value, idx):
        return (value[0], (value[1] + 1))
    g = [([0] * 0) for _ in range(n)]
    gidxs = [([0] * 0) for _ in range(n)]
    for idx_edges in range((n - 1)):
        (a, b) = edges[idx_edges]
        gidxs[a].append(len(g[b]))
        gidxs[b].append(len(g[a]))
        g[a].append(b)
        g[b].append(a)
    parents = np.empty(n, dtype=np.int64)
    order = np.empty(n, dtype=np.int64)
    idxorder = 0
    stack = [0]
    parents[0] = (- 1)
    while stack:
        v = stack.pop()
        p = parents[v]
        order[idxorder] = v
        idxorder += 1
        for u in g[v]:
            if (p != u):
                stack.append(u)
                parents[u] = v
    subtreeres = [([identity] * len(Gv)) for Gv in g]
    for v in order[:0:(- 1)]:
        p = parents[v]
        result = identity
        for idx_Gv in range(len(g[v])):
            u = g[v][idx_Gv]
            subtreeresvi = subtreeres[v][idx_Gv]
            if (p == u):
                parentidx = idx_Gv
            else:
                result = merge(result, subtreeresvi)
        idxp2v = gidxs[v][parentidx]
        subtreeres[p][idxp2v] = add_node(result, v)
    results = ([identity] * n)
    for v in order:
        subtreeresv = subtreeres[v]
        cum = identity
        cumfromtail = [identity]
        for r in subtreeresv[:0:(- 1)]:
            cum = merge(r, cum)
            cumfromtail.append(cum)
        cumfromtail.reverse()
        cum = identity
        for idx_Gv in range(len(g[v])):
            r = subtreeresv[idx_Gv]
            cumt = cumfromtail[idx_Gv]
            u = g[v][idx_Gv]
            idxu2v = gidxs[v][idx_Gv]
            result = add_node(merge(cum, cumt), v)
            subtreeres[u][idxu2v] = result
            cum = merge(cum, r)
        results[v] = add_node(cum, v)
    return np.array(results)
numba_compile([[pow_mod, 'i8(i8,i8)'], [comb_cunstruct, 'Tuple((i8[:],i8[:]))(i8,)'], [comb, 'i8(i8,i8,i8[:],i8[:])'], [rerooting, '(i8,i8[:,:],i8[:],i8[:])']])

def main():
    N = int(sys.stdin.buffer.readline())
    ab = (np.array(sys.stdin.buffer.read().split(), dtype=np.int64).reshape((N - 1), 2) - 1)
    (fac, facinv) = comb_cunstruct(202020