# File changed

import sys
import numpy as np

def numba_compile(numba_config):
    import os, sys
    if (sys.argv[(- 1)] == 'ONLINE_JUDGE'):
        from numba import njit
        from numba.pycc import CC
        cc = CC('my_module')
        for (func, signature) in numba_config:
            globals()[func.__name__] = njit(signature)(func)
            cc.export(func.__name__, signature)(func)
        cc.compile()
        exit()
    elif (os.name == 'posix'):
        exec(f"from my_module import {','.join((func.__name__ for (func, _) in numba_config))}")
        for (func, _) in numba_config:
            globals()[func.__name__] = vars()[func.__name__]
    else:
        from numba import njit
        for (func, signature) in numba_config:
            globals()[func.__name__] = njit(signature, cache=True)(func)
        print('compiled!', file=sys.stderr)
mod = ((10 ** 9) + 7)

def pow_mod(base, exp):
    exp %= (mod - 1)
    res = 1
    while exp:
        if (exp % 2):
            res = ((res * base) % mod)
        base = ((base * base) % mod)
        exp //= 2
    return res

def comb_cunstruct(n):
    fac = np.empty((n + 1), dtype=np.int64)
    facinv = np.empty((n + 1), dtype=np.int64)
    fac[0] = f = 1
    for i in range(1, (n + 1)):
        f = ((f * i) % mod)
        fac[i] = f
    f = pow_mod(f, (- 1))
    for i in range(n, (- 1), (- 1)):
        facinv[i] = f
        f = ((f * i) % mod)
    return (fac, facinv)

def comb(n, r, fac, facinv):
    return ((((fac[n] * facinv[r]) % mod) * facinv[(n - r)]) % mod)

def rerooting(n, edges, fac, facinv):
    identity = (1, 0)

    def merge(a, b):
        return (((((a[0] * b[0]) % mod) * comb((a[1] + b[1]), a[1], fac, facinv)) % mod), (a[1] + b[1]))

    def add_node(value, idx):
        return (value[0], (value[1] + 1))
    G = []
    for _ in range(n):
        G.append(([0] * 0))
    G_idxs = []
    for _ in range(n):
        G_idxs.append(([0] * 0))
    for idx_edges in range((n - 1)):
        (a, b) = edges[idx_edges]
        G_idxs[a].append(len(G[b]))
        G_idxs[b].append(len(G[a]))
        G[a].append(b)
        G[b].append(a)
    parents = np.empty(n, dtype=np.int64)
    order = np.empty(n, dtype=np.int64)
    idx_order = 0
    stack = [0]
    parents[0] = (- 1)
    while stack:
        v = stack.pop()
        p = parents[v]
        order[idx_order] = v
        idx_order += 1
        for u in G[v]:
            if (p != u):
                stack.append(u)
                parents[u] = v
    subtree_res = []
    for Gv in G:
        subtree_res.append(([identity] * len(Gv)))
    for v in order[:0:(- 1)]:
        p = parents[v]
        result = identity
        for idx_Gv in range(len(G[v])):
            u = G[v][idx_Gv]
            subtree_res_v_i = subtree_res[v][idx_Gv]
            if (p == u):
                parent_idx = idx_Gv
            else:
                result = merge(result, subtree_res_v_i)
        idx_p2v = G_idxs[v][parent_idx]
        subtree_res[p][idx_p2v] = add_node(result, v)
    results = ([identity] * n)
    for v in order:
        subtree_res_v = subtree_res[v]
        cum = identity
        cum_from_tail = [identity]
        for r in subtree_res_v[:0:(- 1)]:
            cum = merge(r, cum)
            cum_from_tail.append(cum)
        cum_from_tail.reverse()
        cum = identity
        for idx_Gv in range(len(G[v])):
            r = subtree_res_v[idx_Gv]
            cum_t = cum_from_tail[idx_Gv]
            u = G[v][idx_Gv]
            idx_u2v = G_idxs[v][idx_Gv]
            result = add_node(merge(cum, cum_t), v)
            subtree_res[u][idx_u2v] = result
            cum = merge(cum, r)
        results[v] = add_node(cum, v)
    return np.array(results)
numba_compile([[pow_mod, 'i8(i8,i8)'], [comb_cunstruct, 'Tuple((i8[:],i8[:]))(i8,)'], [comb, 'i8(i8,i8,i8[:],i8[:])'], [rerooting, '(i8,i8[:,:],i8[:],i8[:])']])

def main():
    N = int(sys