import sys
from heapq import *

def first_1(x):
  if x:
    i = 0
    while x & 1 == 0:
      x >>= 1
      i += 1
    return i

def sep_single(s):
  if s:
    r = 1 << (s.bit_length()-1)
    i = s.bit_length()-1
    while s:
      if r & s:
        yield -i, r
        s ^= r
      r >>= 1
      i -= 1

def prepare_to_right(g, x):
  x0, y0 = g[-1]
  if x0 < x and y0:
    y0 = 0
    g.append((x0, 0))
  while x0 < x:
    x0 += 1
    g.append((x0, 0))

def prepare_to_left(g, x):
  x0, y0 = g[-1]
  if x+1 < x0 and y0:
    y0 = 0
    g.append((x0, 0))
  while x+1 < x0:
    x0 -= 1
    g.append((x0, 0))

def append_to_right(g, x, y):
  prepare_to_right(g, x)
  x0, y0 = g[-1]
  if y != y0:
    g.append((x, y))
  g.append((x+1, y))

def subloop_tp_group(g):
  x = 0
  while g&1 == 0:
    g >>= 1
    x += 1
  loop = [(x+1, 0)]
  tail = [(x, 0), (x, 1), (x+1, 1)]
  g >>= 1
  x += 1
  while g:
    while g&1==0:
      g >>= 1
      x += 1
    prepare_to_right(loop, x)
    prepare_to_right(tail, x)
    rev = reversed(loop)
    append_to_right(loop, x, 1)
    loop.append((x+1, 0))
    loop.extend(rev)
    loop.extend(tail)
    append_to_right(loop, x, 0)
    append_to_right(tail, x, 1)
    g >>= 1
    x += 1
  loop.extend(reversed(tail))
  return loop

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_first_1(N):
    assert first_1(1<<N) == N

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_sep_single(N):
    assert list(sep_single(1<<N)) == [(-N, 1<<N)]

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_prepare_to_right(N):
    g = [(0, 0)]
    prepare_to_right(g, N)
    assert g == [(0, 0), (1, 0), (2, 0), (3, 0), (4, 0), (5, 0), (6, 0), (7, 0), (8, 0), (9, 0), (10, 0)]

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_prepare_to_left(N):
    g = [(10, 0)]
    prepare_to_left(g, N)
    assert g == [(10, 0), (9, 0), (8, 0), (7, 0), (6, 0), (5, 0), (4, 0), (3, 0), (2, 0), (1, 0), (0, 0)]

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_append_to_right(N):
    g = [(0, 0)]
    append_to_right(g, N, 1)
    assert g == [(0, 0), (1, 1), (2, 0)]

@pytest.mark.parametrize('N', [1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
def test_subloop_tp_group(N):
    assert subloop_tp_group(1<<N) == [(N+1, 0), (N, 0), (N, 1), (N+1, 1), (N+1, 0)]

@pytest.mark