#!/usr/bin/env python3

import sys
sys.setrecursionlimit(300000)

MOD = 1000000007  # type: int


def get_fraction_mod(numerator, denominator):
    '''
        returns numerator / denominator (mod MOD)
    '''
    inv = pow(denominator, MOD - 2, MOD)
    return numerator * inv % MOD

def make_comb(n, k):
    k = min(k, n - k)
    a = 1
    b = 1
    for i in range(k):
        a = a * (n - i) % MOD
        b = b * (i + 1) % MOD
    ret = get_fraction_mod(a, b)
    return ret

def make_facts(n):
    '''
        make factorials
        0!(=1), 1!, 2!, 3! .... n!
    '''
    fact = [1]
    for i in range(n):
        fact.append((fact[i] * (i + 1)) % MOD)
    return fact


def make_combs(n, k):
    '''
        make [C(n, 0), C(n, 1), C(n, 2) ..... C(n, k)]
        n! / (n - k)! k!
    '''
    facts = make_facts(n)
    invs = [] # inverted for fraction
    for fact in facts:
        invs.append(pow(fact, MOD - 2, MOD))

    ret = []
    for i in range(0, n + 1):
        a = facts[n]
        ret.append(a * invs[i] * invs[n - i] % MOD)
    return ret

def _solve(n):
    dp = [0] * (n + 1)

def solve(n: int, k: int):
    ret = make_comb(n * 2 - 1, n)
    if k < n - 1:
        combs = make_combs(n - 1, n - 1)
        n_combs = make_combs(n, n)
        for i in range(k + 1, n):
            #tmp = make_comb(n, i)
            tmp = n_combs[i]
            t = combs[n - i - 1]
            ret -= tmp * t
            ret %= MOD
    print(ret)
    return

@pytest.mark.parametrize('n, k, expected', [
    (1, 1, 1),
    (2, 1, 2),
    (3, 1, 3),
    (4, 1, 5),
    (5, 1, 7),
    (6, 1, 11),
    (7, 1, 15),
    (8, 1, 22),
    (9, 1, 30),
    (10, 1, 42),
    (11, 1, 56),
    (12, 1, 77),
    (13, 1, 101),
    (14, 1, 135),
    (15, 1, 176),
    (16, 1, 231),
    (17, 1, 297),
    (18, 1, 385),
    (19, 1, 490),
    (20, 1, 627),
    (21, 1, 792),
    (22, 1, 1002),
    (23, 1, 1255),
    (24, 1, 1575),
    (25, 1, 1958),
    (26, 1, 2436),
    (27, 1, 3009),
    (28, 1, 3715),
    (29, 1, 4544),
    (30, 1, 5645),
    (31, 1, 6929),
    (3