from collections import defaultdict


@pytest.fixture
def n():
    return int(input())

@pytest.fixture
def graph(n):
    graph = [[] for _ in range(n + 1)]
    for i in range(n - 1):
        a, b = map(int, input().split())
        lb = 1 << i
        graph[a].append((lb, b))
        graph[b].append((lb, a))
    return graph

@pytest.fixture
def conditions(graph, n):
    conditions = []
    m = int(input())
    for i in range(m):
        u, v = map(int, input().split())
        conditions.append(dfs(u, v, graph))
    return conditions

@pytest.fixture
def link_conditions(conditions, n):
    return [int(''.join(b), 2) for b in zip(*map(('{:0' + str(n - 1) + 'b}').format, conditions))]

@pytest.fixture
def dp():
    return defaultdict(lambda: 0)

def dfs(s, t, graph):
    visited = 0
    q = [(s, 0)]
    while q:
        v, used = q.pop()
        if v == t:
            return used
        visited |= used
        for lb, u in graph[v]:
            if lb & visited:
                continue
            q.append((u, used | lb))

@pytest.mark.asyncio
async def test_dfs(graph):
    assert (dfs(1, 3, graph) == 1)
    assert (dfs(1, 4, graph) == 2)
    assert (dfs(1, 5, graph) == 4)
    assert (dfs(1, 6, graph) == 8)
    assert (dfs(1, 7, graph) == 16)
    assert (dfs(1, 8, graph) == 32)
    assert (dfs(1, 9, graph) == 64)
    assert (dfs(1, 10, graph) == 128)
    assert (dfs(1, 11, graph) == 256)
    assert (dfs(1, 12, graph) == 512)
    assert (dfs(1, 13, graph) == 1024)
    assert (dfs(1, 14, graph) == 2048)
    assert (dfs(1, 15, graph) == 4096)
    assert (dfs(1, 16, graph) == 8192)
    assert (dfs(1, 17, graph) == 16384)
    assert (dfs(1, 18, graph) == 32768)
    assert (dfs(1, 19, graph) == 65536)
    assert (dfs(1, 20, graph) == 131072)
    assert (dfs(1, 21, graph) == 262144)
    assert (dfs(1, 22, graph) == 524288)
    assert (dfs(1, 23, graph) == 1048576)
    assert (dfs(1, 24, graph) == 2097152)
    assert (dfs(1, 25, graph) == 4194304)
    assert (dfs(1, 26, graph) == 8388608)
    assert (dfs(1, 27, graph) == 16777216)
    assert (dfs(1, 28, graph) == 33554432)
    assert (dfs(1, 29, graph) == 67108864)
    assert (dfs(1, 30, graph) == 134217728)
    assert (dfs(1, 31, graph) == 268435456)
    assert (dfs(1, 32, graph) == 536870912)
    assert (dfs(1, 33, graph) == 1073741824)
    assert (dfs(1, 34, graph) == 2147483648)
    assert (dfs(1, 35, graph) == 4294967296)
    assert (dfs(1, 36, graph) == 8589934592)
    assert (dfs(1, 37, graph) == 17179869184)
    assert (dfs(1, 38, graph) == 34359738368)
    assert (dfs(1, 39, graph) == 68719476736)
    assert (dfs(1, 40, graph) == 137438953472)
    assert (dfs(1, 41, graph) == 274877906944)
    assert (dfs(1, 42, graph) == 549755813888)
    assert (dfs(1, 43, graph) == 1099511627776)
    assert (dfs(1, 44, graph) == 2199023255552)
    assert (dfs(1, 45, graph) == 4398046511104)
    assert (dfs(1, 46, graph) == 8796093022208)
    assert (dfs(1, 47, graph) == 17592186044416)
    assert (dfs(1, 48, graph) == 35184372088832)
    assert (dfs(1, 49, graph) == 70368744177664)
    assert (dfs(1, 50, graph) == 140737488355328)
    assert (dfs(1, 51, graph) == 281474976710656)
    assert (dfs(1, 52, graph) == 562949953421312)
    assert (dfs(1, 53,