#!/usr/bin/env python3
import sys
input = sys.stdin.readline

class RollingHash():
    def __init__(self, s):
        self.length = len(s)
        self.base = 1009
        self.mod = (1 << 61) - 1
        self.hash = [0] * (self.length + 1)
        self.pow = [1] * (self.length + 1)

        for i in range(self.length):
            self.hash[i+1] = (self.hash[i] + s[i]) * self.base % self.mod
            self.pow[i+1] = self.pow[i] * self.base % self.mod

    def get(self, l, r):
        t = self.hash[r] - self.hash[l] * self.pow[r-l] % self.mod
        t = (t + self.mod) % self.mod
        return t

@pytest.mark.parametrize('n, a, b, expected', [
    (3, [1, 2, 3], [1, 2, 3], [(0, 0), (1, 1), (2, 2)]),
    (3, [1, 2, 3], [2, 3, 4], [(0, 1), (1, 2), (2, 3)]),
    (3, [1, 2, 3], [3, 4, 5], [(0, 2), (1, 3), (2, 4)]),
    (3, [1, 2, 3], [4, 5, 6], [(0, 3), (1, 4), (2, 5)]),
    (3, [1, 2, 3], [5, 6, 7], [(0, 4), (1, 5), (2, 6)]),
    (3, [1, 2, 3], [6, 7, 8], [(0, 5), (1, 6), (2, 7)]),
    (3, [1, 2, 3], [7, 8, 9], [(0, 6), (1, 7), (2, 8)]),
    (3, [1, 2, 3], [8, 9, 10], [(0, 7), (1, 8), (2, 9)]),
    (3, [1, 2, 3], [9, 10, 11], [(0, 8), (1, 9), (2, 10)]),
    (3, [1, 2, 3], [10, 11, 12], [(0, 9), (1, 10), (2, 11)]),
    (3, [1, 2, 3], [11, 12, 13], [(0, 10), (1, 11), (2, 12)]),
    (3, [1, 2, 3], [12, 13, 14], [(0, 11), (1, 12), (2, 13)]),
    (3, [1, 2, 