# File changed


def num_of_1bit(n: int) -> int:
    'n の立っているビットを数えます。\n    :param n: number\n    :return: number of 1 bit\n    '
    s = 0
    while (n > 0):
        s += (n & 1)
        n >>= 1
    return s

def diff_idx(a: int, b: int) -> int:
    'a と b のビット列を比較してビットの状態が異なる最小の\n    インデックスを返します。ここで、インデックスは 2^i の i \n    に対応する。\n    :param a: number 1\n    :param b: number 2\n    :return: index\n    '
    if (a == b):
        return (- 1)
    idx = 0
    while ((a > 0) or (b > 0)):
        if ((a & 1) != (b & 1)):
            break
        idx += 1
        (a, b) = ((a >> 1), (b >> 1))
    return idx

def remove_bit(n: int, idx: int) -> int:
    'n の idx 番目のビットを消去します。idx は 2^idx に対\n    応します。\n    ex) n = 1011011, idx = 2\n    -> 101111\n\n    :param n: number\n    :param idx: index\n    :return: number removed `idx`th bit\n    '
    upper = ((n >> (idx + 1)) << idx)
    lower = (n & ((1 << idx) - 1))
    return (upper | lower)

def insert_bit(n: int, idx: int, bit: bool) -> int:
    'n の idx 番目にビットを挿入します。\n    ex) n = 101111, idx = 2, bit = True\n    -> 1011111\n    '
    upper = ((n >> idx) << (idx + 1))
    lower = (n & ((1 << idx) - 1))
    insert = (bit << idx)
    return ((upper | insert) | lower)

def route(_from: int, to: int, N: int) -> list:
    '_from から to に至る N ビットの数を全て使ったルートを\n    計算します。\n    :param _from: start\n    :param to: end\n    :param N: number of bit\n    :return: routes\n    '
    if (N == 1):
        return [_from, to]
    di = diff_idx(_from, to)
    a = remove_bit(_from, di)
    b = remove_bit(to, di)
    c = (a ^ 1)
    frombit = ((_from & (1 << di)) != 0)
    tobit = ((to & (1 << di)) != 0)
    firsthalf = map((lambda x: insert_bit(x, di, frombit)), route(a, c, (N - 1)))
    secondhalf = map((lambda x: insert_bit(x, di, tobit)), route(c, b, (N - 1)))
    return (list(firsthalf) + list(secondhalf))

def diff_by_1_bit(N: int, A: int, B: int) -> list:
    numa = num_of_1bit(A)
    numb = num_of_1bit(B)
    if ((abs((numa - numb)) % 2) == 0):
        return []
    return route(A, B, N)
if (__name__ == '__main__'):
    (N, A, B) = map(int, input().split())
    ans = diff_by_1_bit(N, A, B)
    if (len(ans) == 