# File changed


def num_of_1bit(n: int) -> int:
    'Counts the number of 1 bits in the binary representation of n

    Args:
        n (int): The number to count the 1 bits in.

    Returns:
        int: The number of 1 bits in n.
    '
    s = 0
    while (n > 0):
        s += (n & 1)
        n >>= 1
    return s

def diff_idx(a: int, b: int) -> int:
    'Finds the index of the first bit that differs between a and b

    Args:
        a (int): The first number to compare.
        b (int): The second number to compare.

    Returns:
        int: The index of the first bit that differs between a and b.
    '
    if (a == b):
        return (- 1)
    idx = 0
    while ((a > 0) or (b > 0)):
        if ((a & 1) != (b & 1)):
            break
        idx += 1
        (a, b) = ((a >> 1), (b >> 1))
    return idx

def remove_bit(n: int, idx: int) -> int:
    'Removes the bit at the given index from n

    Args:
        n (int): The number to remove the bit from.
        idx (int): The index of the bit to remove.

    Returns:
        int: The number with the bit at the given index removed.
    '
    upper = ((n >> (idx + 1)) << idx)
    lower = (n & ((1 << idx) - 1))
    return (upper | lower)

def insert_bit(n: int, idx: int, bit: bool) -> int:
    'Inserts the given bit at the given index into n

    Args:
        n (int): The number to insert the bit into.
        idx (int): The index of the bit to insert.
        bit (bool): The bit to insert.

    Returns:
        int: The number with the bit inserted at the given index.
    '
    upper = ((n >> idx) << (idx + 1))
    lower = (n & ((1 << idx) - 1))
    insert = (bit << idx)
    return ((upper | insert) | lower)

def route(_from: int, to: int, N: int) -> list:
    'Finds the shortest path between _from and to

    Args:
        _from (int): The starting point.
        to (int): The ending point.
        N (int): The number of nodes.

    Returns:
        list: The shortest path between _from and to.
    '
    if (N == 1):
        return [_from, to]
    di = diff_idx(_from, to)
    a = remove_bit(_from, di)
    b = remove_bit(to, di)
    c = (a ^ 1)
    from_bit = ((_from & (1 << di)) != 0)
    to_bit = ((to & (1 << di)) != 0)
    first_half = map((lambda x: insert_bit(x, di, from_bit)), route(a, c, (N - 1)))
    second_half = map((lambda x: insert_bit(x, di, to_bit)), route(c, b, (N - 1)))