import sys
import numpy as np
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
mod = 1000000007
lim = 1<<10
fact = np.ones(lim, np.int64)
for n in range(1, lim):
    fact[n] = (fact[(n-1)]*n)%mod
factinv = np.ones(lim, np.int64)
factinv[-1] = pow(int(fact[-1]), (mod-2), mod)
for n in range(lim-1, 0, -1):
    factinv[n-1] = (n*factinv[n])%mod
inv = np.zeros(lim, np.int64)
inv[1:] = (fact[:(-1)]*factinv[1:])%mod

def integrate_poly_0x(F):
    f1 = np.zeros_like(F)
    f1[1:] = (F[:(-1)]*inv[1:len(F)])%mod
    return f1

def integrate_poly_x1(F):
    f1 = (- integrate_poly_0x(F))
    f1[0] -= (f1.sum()%mod)
    return (f1%mod)

def integrate_0x(a, F, G):
    '\\int_0^x (ae^{-x} + F(x) + G(x)/e)'
    f1 = integrate_poly_0x(F)
    g1 = integrate_poly_0x(G)
    f1[0] += a
    return (-a, f1, g1)

def integrate_x1(a, F, G):
    '\\int_x^1 (ae^{-x} + F(x) + G(x)/e)'
    f1 = integrate_poly_x1(F)
    g1 = integrate_poly_x1(G)
    g1[0] -= a
    return (a, f1, g1)

def integrate_01(a, F, G):
    (a, F, G) = integrate_x1(a, F, G)
    F[1:] = 0
    G[1:] = 0
    F[0] += a
    return (0, F, G)

def one_to_zero(dp0, dp1, dp2):
    dp0 = integrate_0x(*dp2)
    dp1 = integrate_x1(*dp2)
    dp2 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    return (dp0, dp1, dp2)

def zero_to_one(dp0, dp1, dp2):
    (a0, f0, g0) = integrate_01(*dp0)
    (a1, f1, g1) = integrate_x1(*dp1)
    dp0 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    dp1 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    dp2 = [(a0+a1), (f0+f1), (g0+g1)]
    return (dp0, dp1, dp2)

def zero_to_zero(dp0, dp1, dp2):
    (a0, f0, g0) = integrate_01(*dp0)
    dp0 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    dp1 = [a0, f0, g0]
    dp2 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    return (dp0, dp1, dp2)

def integrate_poly_01_with_exp(F):
    (a, b) = (0, 0)
    F = F.copy()
    while len(F) > 0:
        a += F[0]
        b -= (F.sum()%mod)
        F = (F[1:]*np.arange(1, len(F)))%mod
    return (a, b)

def integrate_01_with_exp(a, F, G):
    ans = np.zeros(3, np.int64)
    if a&1:
        a += mod
    ans[0] += (a//2)
    ans[2] -= (a//2)
    (a, b) = integrate_poly_01_with_exp(F)
    ans[0] += a
    ans[1] += b
    (a, b) = integrate_poly_01_with_exp(G)
    ans[1] += a
    ans[2] += b
    return (ans%mod)

def get_ans(dp0, dp1, dp2):
    ans = np.zeros(3, np.int64)
    (a, F, G) = integrate_01(*dp0)
    ans[0] += (a+F[0])
    ans[1] += G[0]
    (a, F, G) = integrate_01(*dp1)
    ans[0] += (a+F[0])
    ans[1] += G[0]
    ans -= integrate_01_with_exp(*dp1)
    ans += integrate_01_with_exp(*dp2)
    ans %= mod