# File changed

import sys
import numpy as np
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
MOD = 1000000007
lim = (1 << 10)
fact = np.ones(lim, np.int64)
for n in range(1, lim):
    fact[n] = ((fact[(n - 1)] * n) % MOD)
fact_inv = np.ones(lim, np.int64)
fact_inv[(- 1)] = pow(int(fact[(- 1)]), (MOD - 2), MOD)
for n in range((lim - 1), 0, (- 1)):
    fact_inv[(n - 1)] = ((n * fact_inv[n]) % MOD)
inv = np.zeros(lim, np.int64)
inv[1:] = ((fact[:(- 1)] * fact_inv[1:]) % MOD)

def integrate_poly_0x(F):
    'Integrates the polynomial F(x) from 0 to x

    Args:
        F (numpy.ndarray): The polynomial to integrate.

    Returns:
        numpy.ndarray: The integrated polynomial.
    '
    F1 = np.zeros_like(F)
    F1[1:] = ((F[:(- 1)] * inv[1:len(F)]) % MOD)
    return F1

def integrate_poly_x1(F):
    'Integrates the polynomial F(x) from x to 1

    Args:
        F (numpy.ndarray): The polynomial to integrate.

    Returns:
        numpy.ndarray: The integrated polynomial.
    '
    F1 = (- integrate_poly_0x(F))
    F1[0] -= (F1.sum() % MOD)
    return (F1 % MOD)

def integrate_0x(a, F, G):
    'Integrates the polynomial F(x) from 0 to x

    Args:
        a (int): The constant term.
        F (numpy.ndarray): The polynomial to integrate.
        G (numpy.ndarray): The polynomial to integrate.

    Returns:
        tuple: The integrated polynomial.
    '
    F1 = integrate_poly_0x(F)
    G1 = integrate_poly_0x(G)
    F1[0] += a
    return ((- a), F1, G1)

def integrate_x1(a, F, G):
    'Integrates the polynomial F(x) from x to 1

    Args:
        a (int): The constant term.
        F (numpy.ndarray): The polynomial to integrate.
        G (numpy.ndarray): The polynomial to integrate.

    Returns:
        tuple: The integrated polynomial.
    '
    F1 = integrate_poly_x1(F)
    G1 = integrate_poly_x1(G)
    G1[0] -= a
    return (a, F1, G1)

def integrate_01(a, F, G):
    'Integrates the polynomial F(x) from 0 to 1

    Args:
        a (int): The constant term.
        F (numpy.ndarray): The polynomial to integrate.
        G (numpy.ndarray): The polynomial to integrate.

    Returns:
        tuple: The integrated polynomial.
    '
    (a, F, G) = integrate_x1(a, F, G)
    F[1:] = 0
    G[1:] = 0
    F[0] += a
    return (0, F, G)

def one_to_zero(dp0, dp1, dp2):
    'Transforms the polynomials from 1 to 0

    Args:
        dp0 (tuple): The polynomial to transform.
        dp1 (tuple): The polynomial to transform.
        dp2 (tuple): The polynomial to transform.

    Returns:
        tuple: The transformed polynomials.
    '
    dp0 = integrate_0x(*dp2)
    dp1 = integrate_x1(*dp2)
    dp2 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    return (dp0, dp1, dp2)

def zero_to_one(dp0, dp1, dp2):
    'Transforms the polynomials from 0 to 1

    Args:
        dp0 (tuple): The polynomial to transform.
        dp1 (tuple): The polynomial to transform.
        dp2 (tuple): The polynomial to transform.

    Returns:
        tuple: The transformed polynomials.
    '
    (a0, F0, G0) = integrate_01(*dp0)
    (a1, F1, G1) = integrate_x1(*dp1)
    dp0 = [0, np.zeros(N, np.int64), np.zeros(N, np.int64)]
    dp1 = [0, np.zeros(N, np.