# File changed

import sys
import numpy as np
import numba
from numba import njit
i8 = numba.int64
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
A = np.array([1, 2, 3])

@njit(((numba.types.optional(i8),) * 2), cache=True)
def seg_f(x, y):
    'Returns the maximum of two values

    Args:
        x (int): The first value.
        y (int): The second value.

    Returns:
        int: The maximum of the two values.
    '
    if (x is None):
        return y
    if (y is None):
        return x
    return max(x, y)

@njit((i8, i8), cache=True)
def lazy_f(a, b):
    'Returns the sum of two values

    Args:
        a (int): The first value.
        b (int): The second value.

    Returns:
        int: The sum of the two values.
    '
    return (a + b)

@njit((i8, i8), cache=True)
def operate_f(x, a):
    'Returns the sum of two values

    Args:
        x (int): The first value.
        a (int): The second value.

    Returns:
        int: The sum of the two values.
    '
    return (x + a)

@njit((i8[:], i8[:], i8), cache=True)
def _eval_at(seg, lazy, i):
    'Returns the value of the segment at the given index

    Args:
        seg (numpy.ndarray): The segment array.
        lazy (numpy.ndarray): The lazy array.
        i (int): The index to evaluate.

    Returns:
        int: The value of the segment at the given index.
    '
    return operate_f(seg[i], lazy[i])

@njit((i8[:], i8[:], i8), cache=True)
def _propagate_at(seg, lazy, i):
    'Propagates the value of the segment at the given index

    Args:
        seg (numpy.ndarray): The segment array.
        lazy (numpy.ndarray): The lazy array.
        i (int): The index to propagate.
    '
    seg[i] = _eval_at(seg, lazy, i)
    lazy[(i << 1)] = lazy_f(lazy[(i << 1)], lazy[i])
    lazy[((i << 1) | 1)] = lazy_f(lazy[((i << 1) | 1)], lazy[i])
    lazy[i] = 0

@njit((i8[:],), cache=True)
def build(raw_data):
    'Builds the segment tree

    Args:
        raw_data (numpy.ndarray): The raw data to build the segment tree from.

    Returns:
        numpy.ndarray: The segment tree.
    '
    N = len(raw_data)
    seg = np.empty((N + N), np.int64)
    seg[N:] = raw_data
    for i in range((N - 1), 0, (- 1)):
        seg[i] = seg_f(seg[(i << 1)], seg[((i << 1) | 1)])
    return seg

@njit((i8[:], i8[:], i8), cache=True)
def _propagate_above(seg, lazy, i):
    'Propagates the value of the segment above the given index

    Args:
        seg (numpy.ndarray): The segment array.
        lazy (numpy.ndarray): The lazy array.
        i (int): The index to propagate above.
    '
    H = 0
    while ((1 << H) <= i):
        H += 1
    for h in range((H - 1), 0, (- 1)):
        _propagate_at(seg, lazy, (i >> h))

@njit((i8[:], i8[:], i8), cache=True)
def _recalc_above(seg, lazy, i):
    'Recalculates the value of the segment above the given index

    Args:
        seg (numpy.ndarray): The segment array.
        lazy (numpy.ndarray): The lazy array.
        i (int): The index to recalculate above.
    '
    while (i > 1):
        i >>= 1
        seg[i] = seg_f(_eval_at(seg, lazy, (i << 1)), _eval_at(seg, lazy, ((i << 1) | 1)))

@njit((i8[:], i8[:], i8, i8), cache=True)
def set_val(seg, lazy, i, x):
    'Sets the value of the segment at the given index

    Args:
        seg (numpy.ndarray): The segment array.
        lazy (numpy.ndarray): The lazy array.
        i (int): The index to set.
       