import os
import sys

if os.getenv("LOCAL"):
    sys.stdin = open("_in.txt", "r")

sys.setrecursionlimit(10 ** 9)
INF = float("inf")
IINF = 10 ** 18
MOD = 10 ** 9 + 7


# MOD = 998244353


class UnionFind:
    def __init__(self, size=None, nodes=None):
        """
        size か nodes どっちか指定。
        nodes は set、size は list を使う。
        :param int size:
        :param collections.Iterable nodes:
        """
        assert size is not None or nodes is not None
        if size is not None:
            self._parents = [i for i in range(size)]
            self._ranks = [0 for _ in range(size)]
            self._sizes = [1 for _ in range(size)]
        else:
            self._parents = {k: k for k in nodes}
            self._ranks = {k: 0 for k in nodes}
            self._sizes = {k: 1 for k in nodes}

    def unite(self, x, y):
        """
        x が属する木と y が属する木を併合
        :param x:
        :param y:
        """
        x = self.root(x)
        y = self.root(y)
        if x == y:
            return

        # rank が小さい方が下
        if self._ranks[x] > self._ranks[y]:
            # x が root
            self._parents[y] = x
            self._sizes[x] += self._sizes[y]
        else:
            # y が root
            self._parents[x] = y
            self._sizes[y] += self._sizes[x]
            if self._ranks[x] == self._ranks[y]:
                self._ranks[y] += 1

    def root(self, x):
        """
        x が属する木の root
        :param x:
        """
        if self._parents[x] == x:
            return x
        self._parents[x] = self.root(self._parents[x])
        return self._parents[x]

    def size(self, x):
        """
        x が属する木のノード数
        :param x:
        """
        return self._sizes[self.root(x)]


def argsort(li, key=None, reverse=False):
    return [i for _, i in sorted(
        [(a, i) for i, a in enumerate(li)], key=(lambda t: key(t[0])) if key else None, reverse=reverse
    )]


@pytest.fixture
def N():
    return 10

@pytest.fixture
def M():
    return 10

@pytest.fixture
def A(N):
    return [100 for _ in range(N)]

@pytest.fixture
def B(N):
    return [100 for _ in range(N)]

@pytest.fixture
def VU(M):
    return [[1, 2] for _ in range(M)]

@pytest.fixture
def graph(N, VU):
    graph = [[] for _ in range(N)]
    for v, u in VU:
        v -= 1
        u -= 1
        graph[v].append(u)
        graph[u].append(v)
    return graph

@pytest.fixture
def reqs(A, B):
    return [max(0, a - b) for a, b in zip(A, B)]

@pytest.fixture
def uses(B):
    return list(B)

@pytest.fixture
def idx(reqs):
    return argsort(reqs)

@pytest.fixture
def uf(N):
    return UnionFind(size=N)

@pytest.fixture
def seen(N):
    return [False] * N

@pytest.fixture
def ans(N):
    return [INF] * N

def test_argsort(idx, reqs):
    assert idx == [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
    assert reqs == [100, 100, 100, 100, 100, 100, 100, 100, 100, 100]

def test_uf(uf, N):
    assert uf._parents == [i for i in range(N)]
    assert uf._ranks == [0 for _ in range(N)]
    assert uf._sizes == [1 for _ in range(N)]

def test_seen(seen, N):
    assert seen == [False] * N

def test_ans(ans, N):
    assert ans == [INF] * N

def test_graph(graph, N, VU):
    assert graph == [[1, 2], [0], [3], [4], [5], [6], [7], [8], [9], []]

def test_reqs(reqs, A, B):
    assert reqs == [100, 100, 100, 100, 100, 100, 100, 100, 100, 100]

def test_uses(uses, B):
    assert uses == [100, 100, 100, 100, 100, 100, 100, 100, 100, 100]

def test_idx(idx, reqs):
    assert idx == [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
    assert reqs == [100, 100, 100, 100, 100, 100, 100, 100, 100, 100]

def test_uf(uf, N):