from collections import deque


def first_cut(links, colors):
    tmp_links = links.copy()
    for v, neighbors in tmp_links.items():
        while len(neighbors) == 1 and colors[v]:
            del links[v]
            par = neighbors.pop()
            links[par].remove(v)
            v = par
            neighbors = links[par]
    return links


def diameter(links, flags):
    def dfs(s):
        fs = flags[s]
        d, v = 0, 0
        q = deque(sorted((fs + flags[v], v, s) for v in links[s]))
        while q:
            d, v, a = q.popleft()
            for u in links[v]:
                if u == a:
                    continue
                fu = flags[u]
                if fu:
                    q.append((d + 1, u, v))
                else:
                    q.appendleft((d, u, v))
        return d, v

    s = next(iter(links))
    _, t = dfs(s)
    d, _ = dfs(t)
    return d


def solve(links, colors):
    if all(colors):
        return 0

    links = first_cut(links, colors)
    k = len(links)

    if k == 1:
        return 1

    flags = {v: colors[v] ^ (len(link) % 2 == 0) for v, link in links.items()}
    euler_tour = 2 * (k - 1) + sum(flags.values())
    return euler_tour - 2 * diameter(links, flags)


@pytest.mark.parametrize('n, links, colors, expected', [
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [False, True, False, True, False],
        3
    ),
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [True, False, True, False, True],
        3
    ),
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [True, True, True, True, True],
        0
    ),
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [False, False, False, False, False],
        0
    ),
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [False, False, True, True, False],
        2
    ),
    (
        5,
        {
            0: {1, 2},
            1: {0, 2, 3},
            2: {0, 1, 3, 4},
            3: {1, 2, 4},
            4: {2, 3}
        },
        [False, True, False, False, True],
        2
    ),
    (
        5,
        {
            0: {1, 2},
            1: