# File changed

import sys
mod = ((10 ** 9) + 7)
sys.setrecursionlimit(mod)
input = sys.stdin.readline

def root(v):
    'Finds the root of the tree

    Args:
        v (int): The vertex to find the root of.

    Returns:
        int: The root of the tree.
    '
    if (v == par[v]):
        return v
    par[v] = root(par[v])
    return par[v]

def unite(u, v):
    'Unites two trees

    Args:
        u (int): The first tree to unite.
        v (int): The second tree to unite.
    '
    u = root(u)
    v = root(v)
    if (u == v):
        return
    if (rank[u] < rank[v]):
        (u, v) = (v, u)
    par[v] = u
    if (rank[u] == rank[v]):
        rank[u] += 1

def same(u, v):
    'Checks if two vertices are in the same tree

    Args:
        u (int): The first vertex to check.
        v (int): The second vertex to check.

    Returns:
        bool: True if they are in the same tree, False otherwise.
    '
    return (root(u) == root(v))

def kruskal(edges):
    'Performs a Kruskal algorithm on the graph

    Args:
        edges (list): A list of edges to consider.

    Returns:
        tuple: A tuple containing the weight of the tree, the tree itself, and a list of
            booleans indicating which edges were used.
    '
    tree = [[] for _ in range(N)]
    used = ([False] * M)
    weight = 0
    for (i, (w, u, v)) in enumerate(edges):
        if same(u, v):
            continue
        unite(u, v)
        weight += w
        tree[u].append((w, v))
        tree[v].append((w, u))
        used[i] = True
    return (weight, tree, used)

def dfs(v=0, p=(- 1), d=0, w=0):
    'Performs a depth-first search on the tree

    Args:
        v (int, optional): The vertex to start at. Defaults to 0.
        p (int, optional): The parent of the vertex. Defaults to -1.
        d (int, optional): The depth of the vertex. Defaults to 0.
        w (int, optional): The weight of the vertex. Defaults to 0.
    '
    parent[0][v] = p
    depth[v] = d
    max_w[0][v] = w
    for (w, u) in T[v]:
        if (u == p):
            continue
        dfs(u, v, (d + 1), w)

def lca(u, v):
    'Finds the lowest common ancestor of two vertices

    Args:
        u (int): The first vertex.
        v (int): The second vertex.

    Returns:
        int: The lowest common ancestor of the two vertices.
    '
    if (depth[u] > depth[v]):
        (u, v) = (v, u)
    tmp = 0
    while (depth[v] > depth[u]):
        diff = (depth[v] - depth[u])
        k = (diff.bit_length() - 1)
        tmp = max(tmp, max_w[k][v])
        v = parent[k][v]
    if (u == v):
        return tmp
    for k in range((logN - 1), (- 1), (- 1)):
        if (parent[k][u] != parent[k][v]):
            tmp = max(tmp, max_w[k][u], max_w[k][v])
            u = parent[k][u]
            v = parent[k][v]
    return max(tmp, max_w[0][u], max_w[0][v])

def modpow(x, p):
    'Calculates x^p modulo mod

    Args:
        x (int): The base.
        p (int): The exponent.

    Returns:
        int: x^p modulo mod.
    '
    if (p == 0):
        return 1
    elif (p == 1):
        return (x % mod)
    if ((p % 2) == 1):
        return ((x * modpow(x, (p - 1))) % mod)
    return (modpow(((x * x) % mod), (p // 2)) % mod)
(N, M) = map(int, input().split())
logN = (N - 1).bit_length()
X = int(input())
E = ([tuple()] * M)
for i in range(M):
    (u, v, w) = map(int, input().split())
    E[i] = (w, (u - 1), (v - 1))
E = sorted(E, key=(lambda x: x[0]))
par = list(range(N))
rank = ([1] * N)
(W, T, F) = kruskal(E)
depth = ([0] * N)
parent = [([0]