# File changed

import sys
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
import numpy as np
MOD = 998244353
(N, M) = map(int, readline().split())
(A, B, C, D) = [(np.array(list(readline().rstrip())) - 48) for _ in range(4)]

def cumprod(arr, MOD):
    'Calculates the cumulative product of the array

    Args:
        arr (numpy.array): The array to calculate the cumulative product of.
        MOD (int): The modulo to perform the calculations with.

    Returns:
        numpy.array: The cumulative product of the array.
    '
    L = len(arr)
    Lsq = int(((L ** 0.5) + 1))
    arr = np.resize(arr, (Lsq ** 2)).reshape(Lsq, Lsq)
    for n in range(1, Lsq):
        arr[:, n] *= arr[:, (n - 1)]
        arr[:, n] %= MOD
    for n in range(1, Lsq):
        arr[n] *= arr[((n - 1), (- 1))]
        arr[n] %= MOD
    return arr.ravel()[:L]

def make_fact(U, MOD):
    'Calculates the factorials and their inverses

    Args:
        U (int): The maximum value to calculate the factorials for.
        MOD (int): The modulo to perform the calculations with.

    Returns:
        tuple: The factorials and their inverses.
    '
    x = np.arange(U, dtype=np.int64)
    x[0] = 1
    fact = cumprod(x, MOD)
    x = np.arange(U, 0, (- 1), dtype=np.int64)
    x[0] = pow(int(fact[(- 1)]), (MOD - 2), MOD)
    fact_inv = cumprod(x, MOD)[::(- 1)]
    return (fact, fact_inv)
U = (10 ** 6)
(fact, fact_inv) = make_fact(U, MOD)

def cnt_vertical(N, M, A, B, C, D):
    'Counts the number of vertical lines

    Args:
        N (int): The number of rows.
        M (int): The number of columns.
        A (numpy.array): The first array.
        B (numpy.array): The second array.
        C (numpy.array): The third array.
        D (numpy.array): The fourth array.

    Returns:
        int: The number of vertical lines.
    '
    AB = (A + B)
    L = C.sum()
    LU = (A.cumsum() - A)
    LD = (B.cumsum() - B)
    NL = ((((fact[(((LU + LD) + L) - 1)] * fact_inv[(LU + LD)]) % MOD) * fact_inv[(L - 1)]) % MOD)
    R = D.sum()
    RU = (A[::(- 1)].cumsum() - A[::(- 1)])
    RD = (B[::(- 1)].cumsum() - B[::(- 1)])
    NR = ((((fact[(((RU + RD) + R) - 1)] * fact_inv[(RU + RD)]) % MOD) * fact_inv[(R - 1)]) % MOD)
    NR = NR[::(- 1)]
    x = np.ones(N, np.int64)
    x[(AB == 2)] = 2
    coef = cumprod(x, MOD)
    x = np.ones(N, np.int64)
    x[(AB == 2)] = ((MOD + 1) // 2)
    coef_inv = cumprod(x, MOD)
    NL *= coef_inv
    NR *= coef
    NL %= MOD
    NR %= MOD
    NL[(AB == 2)] *= 2
    NL[(AB == 0)] = 0
    NR[(AB == 0)] = 0
    NL_cum = (NL.cumsum() % MOD)
    return (((NL_cum * NR) % MOD).sum() % MOD)

def AB_only(N, A, B):
    'Calculates the number of vertical lines

    Args:
        N (int): The number of rows.
        A (numpy.array): The first array.
        B (numpy.array): The second array.

    Returns:
        int: The number of vertical lines.
    '
    x = np.ones(N, np.int64)
    x[(A + B) == 2] = 2
    return cumprod(x, MOD)[(- 1)]

def ABC_only(N, M, A, B, C):
    'Calculates the number of vertical lines

    Args:
        N (int): The number of rows.
        M (int): The number of columns.
        A (numpy.array): The first array.
        B (numpy.array): The second array.
        C (numpy.array): The third array.

    Returns:
        int: The number of vertical lines.
    '
    AB = (A + B)
    (NA, NB, NC) =