# File changed

from collections import deque
from typing import Optional

class DeletableDeque():
    __slots__ = ['_set', '_deque']

    def __init__(self, *initial_values: int) -> None:
        self._set = set()
        self._deque = deque([])
        if initial_values:
            for v in initial_values:
                self.append(v)

    def __contains__(self, value: int) -> bool:
        return (value in self._set)

    def __len__(self) -> int:
        return len(self._set)

    @property
    def is_empty(self) -> bool:
        return (len(self) == 0)

    @property
    def top(self) -> Optional[int]:
        while (self._deque and (self._deque[(- 1)] not in self._set)):
            self._deque.pop()
        if (not self._deque):
            return None
        return self._deque[(- 1)]

    @property
    def topleft(self) -> Optional[int]:
        while (self._deque and (self._deque[0] not in self._set)):
            self._deque.popleft()
        if (not self._deque):
            return None
        return self._deque[0]

    def pop(self) -> Optional[int]:
        while (self._deque and (self._deque[(- 1)] not in self._set)):
            self._deque.pop()
        if (not self._deque):
            return None
        res = self._deque.pop()
        self._set.discard(res)
        return res

    def popleft(self) -> Optional[int]:
        while (self._deque and (self._deque[0] not in self._set)):
            self._deque.popleft()
        if (not self._deque):
            return None
        res = self._deque.popleft()
        self._set.discard(res)
        return res

    def append(self, value: int) -> None:
        if (value in self._set):
            return
        self._set.add(value)
        self._deque.append(value)

    def appendleft(self, value: int) -> None:
        if (value in self._set):
            return
        self._set.add(value)
        self._deque.appendleft(value)

    def delete(self, value: int) -> None:
        if (value not in self._set):
            return
        self._set.discard(value)

def agc018_b():
    import sys
    from collections import defaultdict
    readline = sys.stdin.buffer.readline
    (N, M) = map(int, readline().split())
    A = [DeletableDeque(*list(map(int, readline().split()))[::(- 1)]) for _ in range(N)]
    res = 301
    for _ in range(M):
        cnt = defaultdict(int)
        for a in A:
            cnt[a.top] += 1
        popular_sport = max(cnt, key=cnt.get)
        res = min(res, cnt[popular_sport])
        for a in A:
            a.delete(popular_sport)
    print(res)
if (__name__ == '__main__'):
    agc018_b()
