class Tree():
    def __init__(self, n, edge, indexed=1):
        self.n = n
        self.tree = [[] for _ in range(n)]
        for e in edge:
            self.tree[e[0] - indexed].append(e[1] - indexed)
            self.tree[e[1] - indexed].append(e[0] - indexed)

    def setroot(self, root):
        self.root = root
        self.parent = [None for _ in range(self.n)]
        self.parent[root] = -1
        self.order = []
        self.order.append(root)
        stack = [root]
        while stack:
            node = stack.pop()
            for adj in self.tree[node]:
                if self.parent[adj] is None:
                    self.parent[adj] = node
                    self.order.append(adj)
                    stack.append(adj)

@pytest.mark.parametrize('N, edge, indexed, expected', [
    (1, [(1, 2)], 1, 'Alice'),
    (2, [(1, 2)], 1, 'Bob'),
    (3, [(1, 2), (2, 3)], 1, 'Alice'),
    (4, [(1, 2), (2, 3), (3, 4)], 1, 'Bob'),
    (5, [(1, 2), (2, 3), (3, 4), (4, 5)], 1, 'Alice'),
    (6, [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6)], 1, 'Bob'),
    (7, [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7)], 1, 'Alice'),
    (8, [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8)], 1, 'Bob'),
    (9, [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8), (8, 9)], 1, 'Alice'),
    (10, [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8), (8, 9), (9, 10)], 1, 'Bob'),
])
def test_grundy_number(N, edge, indexed, expected):
    tree = Tree(N, edge, indexed)
    tree.setroot(0)

    grundy = [0 for _ in range(N)]

    for node in tree.order[::-1]:
        for adj in tree.tree[node]:
            if tree.parent[node] == adj:
                continue
            grundy