class UnionFind:
    def __init__(self, n):
        self.v = [-1] * n

    def find(self, x):
        if self.v[x] < 0:
            return x
        else:
            self.v[x] = self.find(self.v[x])
            return self.v[x]

    def unite(self, x, y):
        x = self.find(x)
        y = self.find(y)

        if x == y:
            return False
        else:
            if self.v[x] > self.v[y]:
                x, y = y, x
            self.v[x] += self.v[y]
            self.v[y] = x
            return True

    def same(self, x, y):
        return self.find(x) == self.find(y)

    def size(self, x):
        return -self.v[self.find(x)]


@pytest.mark.skip
def test_unionfind():
    uf = UnionFind(10)
    assert uf.find(0) == 0
    assert uf.find(1) == 1
    assert uf.find(2) == 2
    assert uf.find(3) == 3
    assert uf.find(4) == 4
    assert uf.find(5) == 5
    assert uf.find(6) == 6
    assert uf.find(7) == 7
    assert uf.find(8) == 8
    assert uf.find(9) == 9

    assert uf.unite(0, 1)
    assert uf.find(0) == uf.find(1)
    assert uf.unite(1, 2)
    assert uf.find(1) == uf.find(2)
    assert uf.unite(2, 3)
    assert uf.find(2) == uf.find(3)
    assert uf.unite(3, 4)
    assert uf.find(3) == uf.find(4)
    assert uf.unite(4, 5)
    assert uf.find(4) == uf.find(5)
    assert uf.unite(5, 6)
    assert uf.find(5) == uf.find(6)
    assert uf.unite(6, 7)
    assert uf.find(6) == uf.find(7)
    assert uf.unite(7, 8)
    assert uf.find(7) == uf.find(8)
    assert uf.unite(8, 9)
    assert uf.find(8) == uf.find(9)

    assert not uf.unite(0, 1)
    assert uf.find(0) == uf.find(1)
    assert not uf.unite(1, 2)
    assert uf.find(1) == uf.find(2)
    assert not uf.unite(2, 3)
    assert uf.find(2) == uf.find(3)
    assert not uf.unite(3, 4)
    assert uf.find(3) == uf.find(4)
    assert not uf.unite(4, 5)
    assert uf.find(4) == uf.find(5)
    assert not uf.unite(5, 6)
    assert uf.find(5) == uf.find(6)
    assert not uf.unite(6, 7)
    assert uf.find(6) == uf.find(7)
    assert not uf.unite(7, 8)
    assert uf.find(7) == uf.find(8)
    assert not uf.unite(8, 9)
    assert uf.find(8) == uf.find(9)

    assert uf.unite(0, 9)
    assert uf.find(0) == uf.find(9)
    assert uf.unite(1, 8)
    assert uf.find(1) == uf.find(8)
    assert uf.unite(2, 7)
    assert uf.find(2) == uf.find(7)
   