import heapq
class UnionFind:
    def __init__(self, n):
        self.n = n
        self.parent = [i for i in range(n)]
        self.rank = [0] * n
    
    def find(self, x):
        if self.parent[x] != x:
            self.parent[x] = self.find(self.parent[x])
        return self.parent[x]

    def union(self, x, y):
        x, y = self.find(x), self.find(y)
        if x == y: return
        
        if self.rank[x] < self.rank[y]:
            self.parent[x] = y
        else:
            self.parent[y] = x
            self.rank[x] += (self.rank[x] == self.rank[y])

@pytest.mark.parametrize('n, expected', [
    (1, 0),
    (2, 0),
    (3, 1),
    (4, 2),
    (5, 3),
    (6, 4),
    (7, 5),
    (8, 6),
    (9, 7),
    (10, 8),
    (11, 9),
    (12, 10),
    (13, 11),
    (14, 12),
    (15, 13),
    (16, 14),
    (17, 15),
    (18, 16),
    (19, 17),
    (20, 18),
    (21, 19),
    (22, 20),
    (23, 21),
    (24, 22),
    (25, 23),
    (26, 24),
    (27, 25),
    (28, 26),
    (29, 27),
    (30, 28),
    (31, 29),
    (32, 30),
    (33, 31),
    (34, 32),
    (35, 33),
    (36, 34),
    (37, 35),
    (38, 36),
    (39, 37),
    (40, 38),
    (41, 39),
    (42, 40),
    (43, 41),
    (44, 42),
    (45, 43),
    (46, 44),
    (47, 45),
    (48, 46),
    (49, 47),
    (50, 48),
    (51, 49),
    (52, 50),
    (53, 51),
    (54, 52),
    (55, 53),
    (56, 54),
    (57, 55),
    (58, 56),
    (59, 57),
    (60, 58),
    (61, 59),
    (62, 6