# File changed

import sys
import heapq
import re
from itertools import permutations
from bisect import bisect_left, bisect_right
from collections import Counter, deque
from fractions import gcd
from math import factorial, sqrt, ceil
from functools import lru_cache, reduce
INF = (1 << 60)
MOD = 1000000007
sys.setrecursionlimit((10 ** 7))

class UnionFind():

    def __init__(self, n):
        'Initializes the UnionFind data structure

        Args:
            n (int): The number of elements in the data structure.
        '
        self.n = n
        self.parents = ([(- 1)] * n)

    def find(self, x):
        'Finds the root of the tree that x is in

        Args:
            x (int): The element to find the root for.

        Returns:
            int: The root of the tree that x is in.
        '
        if (self.parents[x] < 0):
            return x
        else:
            self.parents[x] = self.find(self.parents[x])
            return self.parents[x]

    def union(self, x, y):
        'Unions two trees together

        Args:
            x (int): The first tree to union.
            y (int): The second tree to union.
        '
        x = self.find(x)
        y = self.find(y)
        if (x == y):
            return
        if (self.parents[x] > self.parents[y]):
            (x, y) = (y, x)
        self.parents[x] += self.parents[y]
        self.parents[y] = x

    def size(self, x):
        'Returns the size of the tree that x is in

        Args:
            x (int): The element to find the size of the tree for.

        Returns:
            int: The size of the tree that x is in.
        '
        return (- self.parents[self.find(x)])

    def same(self, x, y):
        'Returns whether or not x and y are in the same tree

        Args:
            x (int): The first element to check.
            y (int): The second element to check.

        Returns:
            bool: Whether or not x and y are in the same tree.
        '
        return (self.find(x) == self.find(y))

    def members(self, x):
        'Returns a list of all the members in the tree that x is in

        Args:
            x (int): The element to find the members of the tree for.

        Returns:
            list: A list of all the members in the tree that x is in.
        '
        root = self.find(x)
        return [i for i in range(self.n) if (self.find(i) == root)]

    def roots(self):
        'Returns a list of all the roots in the UnionFind data structure

        Returns:
            list: A list of all the roots in the UnionFind data structure.
        '
        return [i for (i, x) in enumerate(self.parents) if (x < 0)]

    def group_count(self):
        'Returns the number of groups in the UnionFind data structure

        Returns:
            int: The number of groups in the UnionFind data structure.
        '
        return len(self.roots())

    def all_group_members(self):
        'Returns a dictionary of all the members in each group

        Returns:
            dict: A dictionary of all the members in each group.
        '
        return {r: self.members(r) for r in self.roots()}

    def __str__(self):
        'Returns a string representation of the UnionFind data structure

        Returns:
            str: A string representation of the UnionFind data structure.
        '
        return '\n'.join(('{}: {}'.format(r, self.members(r)) for r in self.roots()))

def dijkstra_heap(s, edge, n):
    'Performs a Dijkstra search on a graph

    Args:
        s (int): The starting node.
        edge (list): A list of edges in the graph.
        n (int): The number of nodes in the graph.

    Returns:
        list: A list of the shortest distances from the starting node to each node in the graph.
    '
    d = ([(10 ** 20)] * n)
    used = ([True] * n)
    d[s] = 0
    used[s] = False
    edgelist = []
    for (a, b) in edge[s]:
        heapq.heappush(edgelist, ((a * (10 ** 6)) + b))
    while len(edgelist):
        minedge = heapq.heappop(edgelist)
        if (not used[(minedge % (10 ** 6))]):
            continue
        v = (minedge % (10 ** 6))
        d[v] = (minedge // (10 ** 6))
        used[v] = False
        for e in edge[v]:
            if used[e[1]]:
                heapq.heappush(edgelist, (((e[0] + d[v]) * (10 ** 6)) + e[1]))
    return d

def factorization(n):
    'Returns a list of the prime factorization of a number

    Args:
        n (int): The number to factorize.

    Returns:
        list: A list of the prime factorization of a number.
    '
    arr = []
    temp = n
    for i in range(2, (int((- ((- (n ** 0.5)) // 1))) + 1)):
        if ((temp % i) == 0):
            cnt = 0
            while ((temp % i) == 0):
                cnt += 1
                temp //= i
            arr.append([i, cnt])
    if (temp != 1):