# File changed

import sys
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines
from heapq import heappop, heappush
import itertools


class MinCostFlow:
    def __init__(self, n, source, sink):
        self.n = n
        self.g = [[] for _ in range(n)]
        self.source = source
        self.sink = sink

    def add_edge(self, fr, to, cap, cost):
        n1 = len(self.g[fr])
        n2 = len(self.g[to])
        self.g[fr].append([to, cap, cost, n2])
        self.g[to].append([fr, 0, (- cost), n1])

    def min_cost(self, flow, negative_edge=False):
        if negative_edge:
            raise ValueError
        n = self.n
        g = self.g
        source = self.source
        sink = self.sink
        inf = 10 ** 18
        prevv = [0] * n
        preve = [0] * n
        h = [0] * n
        mincost = 0
        while flow:
            dist = [inf] * n
            dist[source] = 0
            q = [source]
            mask = (1 << 20) - 1
            while q:
                x = heappop(q)
                dv = (x >> 20)
                v = (x & mask)
                if dist[v] < dv:
                    continue
                if v == sink:
                    break
                for i, (w, cap, cost, rev) in enumerate(g[v]):
                    dw = ((dist[v] + cost) + h[v]) - h[w]
                    if not cap or dist[w] <= dw:
                        continue
                    dist[w] = dw
                    prevv[w] = v
                    preve[w] = i
                    heappush(q, (dw << 20) + w)
            if dist[sink] == inf:
                raise Exception('No Flow Exists')
            for v, d in enumerate(dist):
                h[v] += d
            d = flow
            v = sink
            while v != source:
                pv = prevv[v]
                pe = preve[v]
                cap = g[pv][pe][1]
                if d > cap:
                    d = cap
                v = pv
            mincost += (d * h[sink])
            flow -= d
            v = sink
            while v != source:
                pv = prevv[v]
                pe = preve[v]
                g[pv][pe][1] -= d
                rev = g[pv][pe][3]
                g[v][rev][1] += d
                v = pv
        return mincost

(h, w) = map(int, readline().split())
a = list(map(int, read().split()))
n = (((2 * h) * w) + 2)
source = (n - 2)
sink = (n - 1)
g = MinCostFlow(n, source, sink)
add = g.add_edge
x = 10 ** 6
add(fr=source, to=0, cap=2, cost=0)
add((((2 * h) * w) - 1), sink, 2, 0)
for x, a in enumerate(a):
    add((x + x), ((x + x) + 1), 1, x)
    add((x + x), ((x + x) + 1), 1, (x - a))
for i, j in itertools.product(range(h), range((w - 1))):
    x = ((w * i) + j)
    y = (x + 1)
    add(((x + x) + 1), (y + y), 1, 0)
for i, j in itertools.product(range((h - 1)), range(w)):
    x = ((w * i) + j)
    y = (x + w)
    add(((x + x) + 1), (y + y), 1, 0)
cost = g.min_cost(2)
answer = (((2 * ((h + w) - 1)) * x) - cost)
print(answer)





















































































































































































































































































































































































































































